@@ -107,6 +107,7 @@ public class PreferenceManager implements PropertyManager {
     public static final String SAM_FILTER_SECONDARY_ALIGNMENTS = "SAM.FILTER_SECONDARY_ALIGNMENTS";
     public static final String SAM_FILTER_SUPPLEMENTARY_ALIGNMENTS = "SAM.FILTER_SUPPLEMENTARY_ALIGNMENTS";
     public static final String SAM_FILTER_URL = "SAM.FILTER_URL";
+    public static final String SAM_HIDDEN_TAGS = "SAM.HIDDEN_TAGS";
     public static final String SAM_MAX_VISIBLE_RANGE = "SAM.MAX_VISIBLE_RANGE";
     public static final String SAM_SHOW_DUPLICATES = "SAM.SHOW_DUPLICATES";
     public static final String SAM_SHOW_SOFT_CLIPPED = "SAM.SHOW_SOFT_CLIPPED";
@@ -210,6 +211,8 @@ public class PreferenceManager implements PropertyManager {
     //public static final String CHECKED_RESOURCES_KEY = "CHECKED_RESOURCES_KEY";
     public static final String DEFINE_GENOME_INPUT_DIRECTORY_KEY = "DEFINE_GENOME_INPUT_DIRECTORY_KEY";
 
+    public static final String VARIANT_COLOR_BY_ALLELE_FREQ = "VARIANT_COLOR_BY_ALLELE_FREQ";
+
     public static final String PROBE_MAPPING_KEY = "PROBE_MAPPING_KEY";
     public static final String PROBE_MAPPING_FILE = "PROBE_MAPPING_FILE";
     public static final String USE_PROBE_MAPPING_FILE = "USE_PROBE_MAPPING_FILE";
@@ -297,6 +300,8 @@ public class PreferenceManager implements PropertyManager {
 
     public static final String SESSION_RELATIVE_PATH = "SESSION.RELATIVE_PATH";
 
+    public static final String CHECK_VERSION = "CHECK_VERSION";
+
     IGVPreferences preferences;
     Map<String, String> defaultValues;
 
@@ -697,33 +702,6 @@ public class PreferenceManager implements PropertyManager {
     }
 
 
-    /**
-     * @param directory
-     */
-    public void setLastSessionDirectory(File directory) {
-
-        put(LAST_SESSION_DIRECTORY, directory.getAbsolutePath());
-    }
-
-    /**
-     * @return
-     */
-    public File getLastSessionDirectory() {
-
-        File sessionDirectory = null;
-
-        String lastFilePath = get(LAST_SESSION_DIRECTORY, null);
-
-        if (lastFilePath != null) {
-
-            // Create the session directory
-            sessionDirectory = new File(lastFilePath);
-        }
-
-        return sessionDirectory;
-    }
-
-
     /**
      * @param recentSessions
      */
@@ -879,7 +857,7 @@ public class PreferenceManager implements PropertyManager {
      * @param type
      * @return
      */
-    public ContinuousColorScale getDefaultColorScale(TrackType type) {
+    public static ContinuousColorScale getDefaultColorScale(TrackType type) {
         switch (type) {
             case LOH:
                 return new ContinuousColorScale(0, -1, 0, 1, Color.red, UIConstants.LIGHT_YELLOW, Color.blue);
@@ -895,20 +873,24 @@ public class PreferenceManager implements PropertyManager {
                 return cs;
 
             case GENE_EXPRESSION:
-                cs = new ContinuousColorScale(-0.1, -1.5, 0.1, 1.5, Color.BLUE, Color.WHITE, Color.RED);
+                cs = getDefaultColorScale(Color.BLUE, Color.WHITE, Color.RED);
                 cs.setNoDataColor(new Color(225, 225, 225));
                 return cs;
 
             case COPY_NUMBER:
             case ALLELE_SPECIFIC_COPY_NUMBER:
             case CNV:
-                return new ContinuousColorScale(-0.1, -1.5, 0.1, 1.5, Color.BLUE, Color.WHITE, Color.RED);
+                return getDefaultColorScale(Color.BLUE, Color.WHITE, Color.RED);
 
             default:
                 return null;
         }
     }
 
+    public static ContinuousColorScale getDefaultColorScale(Color negColor, Color neutralColor, Color posColor) {
+        return new ContinuousColorScale(-0.1, -1.5, 0.1, 1.5, negColor, neutralColor, posColor);
+    }
+
     /**
      * Original labels:  Indel, Missense, Nonsesne, Splice_site, Synonymous, Targetd_Region, Unknown
      * Nico's labels:   Synonymous, Missense, Truncating, Non-coding_Transcript, Other_AA_changing, Other_likely_neutral.
@@ -1091,6 +1073,7 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(SAM_BASE_QUALITY_MIN, "5");
         defaultValues.put(SAM_BASE_QUALITY_MAX, "20");
         defaultValues.put(SAM_FILTER_URL, null);
+        defaultValues.put(SAM_HIDDEN_TAGS, "MD,SA");
         defaultValues.put(SAM_QUALITY_THRESHOLD, "0");
         defaultValues.put(SAM_ALLELE_THRESHOLD, "0.2f");
         defaultValues.put(SAM_ALLELE_USE_QUALITY, "true");
@@ -1232,6 +1215,8 @@ public class PreferenceManager implements PropertyManager {
         defaultValues.put(AF_REF_COLOR, "0,0,220");
         defaultValues.put(AF_VAR_COLOR, "255,0,0");
 
+        defaultValues.put(VARIANT_COLOR_BY_ALLELE_FREQ, "true");
+
         defaultValues.put(SASHIMI_SHOW_COVERAGE, "true");
 
         defaultValues.put(ENABLE_GOOGLE_MENU, "false");
@@ -1247,6 +1232,7 @@ public class PreferenceManager implements PropertyManager {
 
         defaultValues.put(SHOW_LOS, "true");
 
+        defaultValues.put(CHECK_VERSION, "true");
     }
 
     /**
