@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.bbfile;
@@ -52,7 +66,7 @@ import java.util.Map;
 *   chromosome tree searches, and getChromosomeID returns a chromosome ID for
 *   searches in the R+ index tree.
 *
-**/ 
+**/
 public class BPTree {
 
     private static Logger log = Logger.getLogger(BPTree.class);
@@ -191,16 +205,13 @@ public class BPTree {
     *   Returns a search key for the mChromosome region  which  can
     *   be used to search for a corresponding section in the B+ tree.
     *
-    *   According the the spec the key is the "first keySize characters of chromosome name, padded with zeroes if needed.
+    *   According the the spec the key is the "first keySize characters of chromosome name"
     * */
     public String getChromosomeKey(String chromosome) {
 
         String key = chromosomeKeyCache.get(chromosome);
         if(key == null) {
-            char [] keyChars = new char[keySize];
-            char [] chrChars = chromosome.toCharArray();
-            System.arraycopy(chrChars, 0, keyChars, 0, Math.min(keySize, chrChars.length));
-            key = new String(keyChars);
+            key = chromosome.length() <= keySize ? chromosome : chromosome.substring(0, keySize);
             chromosomeKeyCache.put(chromosome, key);
         }
         return key;
@@ -371,7 +382,6 @@ public class BPTree {
                }
            }
         }
-
         return chromID;
     }
 
@@ -494,7 +504,7 @@ public class BPTree {
 
         highestID = thisNode.getHighestChromID();
         if(highestID < startChromID)
-            return; 
+            return;
 
         // search down the tree recursively starting with the root node
         if(thisNode.isLeaf())
@@ -632,7 +642,7 @@ public class BPTree {
                }
 
                String key = new String(keychars).trim();
-                
+
                int chromID;
                int chromSize;
                long childOffset;
@@ -660,7 +670,7 @@ public class BPTree {
 
                    childNode = readBPTreeNode(this.fis, childOffset, thisNode, isLowToHigh);
 
-                   // insert child node item 
+                   // insert child node item
                    BPTreeChildNodeItem childItem = new BPTreeChildNodeItem(item, key, childNode);
                    thisNode.insertItem(childItem);
                 }
@@ -678,4 +688,4 @@ public class BPTree {
    }
 
 
-}
\ No newline at end of file
+}
