@@ -42,6 +42,7 @@ public class BasicFeature extends AbstractFeature {
 
     private static Logger log = Logger.getLogger(BasicFeature.class);
 
+    String representation;
     protected List<Exon> exons;
     protected int level = 1;
     protected float score = Float.NaN;
@@ -88,8 +89,16 @@ public class BasicFeature extends AbstractFeature {
         this.link = feature.link;
         this.thickStart = feature.thickStart;
         this.thickEnd = feature.thickEnd;
+        this.attributes = feature.attributes;
     }
 
+    public String getRepresentation() {
+        return representation;
+    }
+
+    public void setRepresentation(String representation) {
+        this.representation = representation;
+    }
 
     /**
      * @param identifier
