@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -15,9 +29,11 @@
  */
 package org.broad.igv.sam;
 
+import com.google.common.collect.HashBasedTable;
+import com.google.common.collect.Table;
 import org.apache.log4j.Logger;
+import org.broad.igv.feature.Range;
 import org.broad.igv.feature.Strand;
-import org.broad.igv.sam.AlignmentInterval.Row;
 
 import java.util.*;
 
@@ -34,7 +50,7 @@ public class AlignmentPacker {
      * Minimum gap between the end of one alignment and start of another.
      */
     public static final int MIN_ALIGNMENT_SPACING = 5;
-    private final Comparator<Alignment> lengthComparator = new Comparator<Alignment>() {
+    private static final Comparator<Alignment> lengthComparator = new Comparator<Alignment>() {
         public int compare(Alignment row1, Alignment row2) {
             return (row2.getEnd() - row2.getStart()) -
                     (row1.getEnd() - row2.getStart());
@@ -42,66 +58,225 @@ public class AlignmentPacker {
         }
     };
 
+    private static final String NULL_GROUP_VALUE = "Because google-guava tables don't support a null key, we use a special value" +
+            " for null keys. It doesn't matter much what it is, but we want to avoid collisions. I find it unlikely that " +
+            " this sentence will ever be used as a group value";
+    public static final int tenMB = 10000000;
+
     /**
-     * Allocates each alignment to the rows such that there is no overlap.
-     *
-     * @param iter Iterator of alignments, sorted by start position
-     * @param end  Last index of the last alignment
-     * @param renderOptions
+     * Allocates each alignment to row such that there is no overlap.
      */
-    public LinkedHashMap<String, List<AlignmentInterval.Row>> packAlignments(
-            Iterator<Alignment> iter,
-            int end,
+    public PackedAlignments packAlignments(
+            AlignmentInterval interval,
             AlignmentTrack.RenderOptions renderOptions) {
 
-        if(renderOptions == null) renderOptions = new AlignmentTrack.RenderOptions();
+        if (renderOptions == null) renderOptions = new AlignmentTrack.RenderOptions();
 
-        LinkedHashMap<String, List<AlignmentInterval.Row>> packedAlignments = new LinkedHashMap<String, List<Row>>();
-        boolean pairAlignments = renderOptions.isViewPairs() || renderOptions.isPairedArcView();
+        LinkedHashMap<String, List<Row>> packedAlignments = new LinkedHashMap<String, List<Row>>();
+
+        boolean isPairedAlignments = renderOptions.isViewPairs() || renderOptions.isPairedArcView();
 
-        if (iter == null || !iter.hasNext()) {
-            return packedAlignments;
-        }
 
         if (renderOptions.groupByOption == null) {
             List<Row> alignmentRows = new ArrayList<Row>(10000);
-            pack(iter, end, pairAlignments, alignmentRows);
+            pack(interval.getAlignments(), isPairedAlignments, alignmentRows);
             packedAlignments.put("", alignmentRows);
         } else {
+
             // Separate alignments into groups.
-            List<Alignment> nullGroup = new ArrayList<Alignment>();
-            HashMap<String, List<Alignment>> groupedAlignments = new HashMap<String, List<Alignment>>();
+            Map<String, List<Alignment>> groupedAlignments = new HashMap<String, List<Alignment>>();
+            Iterator<Alignment> iter = interval.getAlignmentIterator();
             while (iter.hasNext()) {
                 Alignment alignment = iter.next();
                 String groupKey = getGroupValue(alignment, renderOptions);
-                if (groupKey == null) nullGroup.add(alignment);
-                else {
-                    List<Alignment> group = groupedAlignments.get(groupKey);
-                    if (group == null) {
-                        group = new ArrayList<Alignment>(1000);
-                        groupedAlignments.put(groupKey, group);
-                    }
-                    group.add(alignment);
+                if (groupKey == null) {
+                    groupKey = NULL_GROUP_VALUE;
                 }
+                List<Alignment> groupList = groupedAlignments.get(groupKey);
+                if (groupList == null) {
+                    groupList = new ArrayList<Alignment>(1000);
+                    groupedAlignments.put(groupKey, groupList);
+                }
+                groupList.add(alignment);
             }
 
-            // Now alphabetize (sort) and pack the groups
+
+            // Now alphabetize (sort) and packGroup the groups
             List<String> keys = new ArrayList<String>(groupedAlignments.keySet());
             Comparator<String> groupComparator = getGroupComparator(renderOptions.groupByOption);
             Collections.sort(keys, groupComparator);
+
             for (String key : keys) {
+                if (key.equals(NULL_GROUP_VALUE)) continue;
                 List<Row> alignmentRows = new ArrayList<Row>(10000);
                 List<Alignment> group = groupedAlignments.get(key);
-                pack(group.iterator(), end, pairAlignments, alignmentRows);
+                pack(group, isPairedAlignments, alignmentRows);
                 packedAlignments.put(key, alignmentRows);
             }
+
+            //Put null valued group at end
             List<Row> alignmentRows = new ArrayList<Row>(10000);
-            pack(nullGroup.iterator(), end, pairAlignments, alignmentRows);
+            List<Alignment> group = groupedAlignments.get(NULL_GROUP_VALUE);
+            pack(group, isPairedAlignments, alignmentRows);
             packedAlignments.put("", alignmentRows);
         }
 
-        return packedAlignments;
+        List<AlignmentInterval> tmp = new ArrayList<AlignmentInterval>();
+        tmp.add(interval);
+        return new PackedAlignments(tmp, packedAlignments);
+    }
 
+
+    private void pack(List<Alignment> alList, boolean pairAlignments, List<Row> alignmentRows) {
+
+        Map<String, PairedAlignment> pairs = null;
+        if (pairAlignments) {
+            pairs = new HashMap<String, PairedAlignment>(1000);
+        }
+
+        // Allocate alignemnts to buckets for each range.
+        // We use priority queues to keep the buckets sorted by alignment length.  However this  is probably a needless
+        // complication,  any collection type would do.
+
+        int totalCount = 0;
+
+
+        if (alList == null || alList.size() == 0) return;
+
+        Range curRange = getAlignmentListRange(alList);
+
+        BucketCollection bucketCollection;
+
+        // Use dense buckets for < 10,000,000 bp windows sparse otherwise
+        int bpLength = curRange.getLength();
+
+        if (bpLength < tenMB) {
+            bucketCollection = new DenseBucketCollection(bpLength, curRange);
+        } else {
+            bucketCollection = new SparseBucketCollection(curRange);
+        }
+
+
+        int curRangeStart = curRange.getStart();
+        for (Alignment al : alList) {
+
+            if (al.isMapped()) {
+                Alignment alignment = al;
+                if (pairAlignments &&
+                        al.isPaired() &&
+                        al.isPrimary() &&
+                        al.getMate().isMapped() &&
+                        al.getMate().getChr().equals(al.getChr())) {
+                    String readName = al.getReadName();
+                    PairedAlignment pair = pairs.get(readName);
+                    if (pair == null) {
+                        pair = new PairedAlignment(al);
+                        pairs.put(readName, pair);
+                        alignment = pair;
+                    } else {
+                        // Add second alignment to pair.
+                        pair.setSecondAlignment(al);
+                        pairs.remove(readName);
+                        continue;
+
+                    }
+                }
+
+                // Negative "bucketNumbers" can arise with soft clips at the left edge of the chromosome. Allocate
+                // these alignments to the first bucket.
+                int bucketNumber = Math.max(0, al.getStart() - curRangeStart);
+                if (bucketNumber < bucketCollection.getBucketCount()) {
+                    PriorityQueue<Alignment> bucket = bucketCollection.get(bucketNumber);
+                    if (bucket == null) {
+                        bucket = new PriorityQueue<Alignment>(5, lengthComparator);
+                        bucketCollection.set(bucketNumber, bucket);
+                    }
+                    bucket.add(alignment);
+                    totalCount++;
+                } else {
+                    log.debug("Alignment out of bounds. name: " + alignment.getReadName() + " startPos:" + alignment.getStart());
+                }
+            }
+        }
+        bucketCollection.finishedAdding();
+
+
+        // Now allocate alignments to rows.
+        long t0 = System.currentTimeMillis();
+        int allocatedCount = 0;
+        Row currentRow = new Row();
+
+        while (allocatedCount < totalCount) {
+
+
+            curRange = bucketCollection.getRange();
+
+            curRangeStart = curRange.getStart();
+            int nextStart = curRangeStart;
+            List<Integer> emptyBuckets = new ArrayList<Integer>(100);
+
+            while (true) {
+                int bucketNumber = nextStart - curRangeStart;
+                PriorityQueue<Alignment> bucket = bucketCollection.getNextBucket(bucketNumber, emptyBuckets);
+
+                // Pull the next alignment out of the bucket and add to the current row
+                if (bucket != null) {
+                    Alignment alignment = bucket.remove();
+                    currentRow.addAlignment(alignment);
+                    allocatedCount++;
+
+                    nextStart = alignment.getEnd() + MIN_ALIGNMENT_SPACING;
+
+                }
+
+                //Reached the end of this range, move to the next
+                if (bucket == null || nextStart > curRange.getEnd()) {
+                    //Remove empty buckets.  This has no affect on the dense implementation,
+                    //they are removed on the fly, but is needed for the sparse implementation
+                    bucketCollection.removeBuckets(emptyBuckets);
+                    emptyBuckets.clear();
+                    break;
+                }
+            }
+
+
+            // We've reached the end of the interval,  start a new row
+            if (currentRow.alignments.size() > 0) {
+                alignmentRows.add(currentRow);
+            }
+            currentRow = new Row();
+        }
+        if (log.isDebugEnabled()) {
+            long dt = System.currentTimeMillis() - t0;
+            log.debug("Packed alignments in " + dt);
+        }
+
+        // Add the last row
+        if (currentRow != null && currentRow.alignments.size() > 0) {
+            alignmentRows.add(currentRow);
+        }
+
+
+    }
+
+
+    /**
+     * Gets the range over which alignmentsList spans. Asssumes all on same chr, and sorted
+     *
+     * @param alignmentsList
+     * @return
+     */
+    private Range getAlignmentListRange(List<Alignment> alignmentsList) {
+        if (alignmentsList == null || alignmentsList.size() == 0) return null;
+        Alignment firstAlignment = alignmentsList.get(0);
+
+        int minStart = firstAlignment.getStart();
+        int maxEnd = firstAlignment.getEnd();
+        for (Alignment alignment : alignmentsList) {
+            maxEnd = Math.max(maxEnd, alignment.getEnd());
+        }
+        return new Range(firstAlignment.getChr(), minStart,
+                maxEnd);
     }
 
     private Comparator<String> getGroupComparator(AlignmentTrack.GroupOption groupByOption) {
@@ -137,6 +312,8 @@ public class AlignmentPacker {
                 return String.valueOf(al.isNegativeStrand());
             case SAMPLE:
                 return al.getSample();
+            case LIBRARY:
+                return al.getLibrary();
             case READ_GROUP:
                 return al.getReadGroup();
             case TAG:
@@ -145,6 +322,7 @@ public class AlignmentPacker {
             case FIRST_OF_PAIR_STRAND:
                 Strand strand = al.getFirstOfPairStrand();
                 String strandString = strand == Strand.NONE ? null : strand.toString();
+                System.out.println(strandString);
                 return strandString;
             case PAIR_ORIENTATION:
                 PEStats peStats = AlignmentRenderer.getPEStats(al, renderOptions);
@@ -155,165 +333,23 @@ public class AlignmentPacker {
                 return type.name();
             case MATE_CHROMOSOME:
                 ReadMate mate = al.getMate();
-                if (mate == null) return null;
-                return mate.getChr();
+                if (mate == null) {
+                    return null;
+                } else if (mate.isMapped() == false) {
+                    return "UNMAPPED";
+                } else {
+                    return mate.getChr();
+                }
+            case SUPPLEMENTARY:
+                return String.valueOf(!al.isSupplementary());
         }
         return null;
     }
 
-    private void pack(Iterator<Alignment> iter, int end, boolean pairAlignments,
-                      List<Row> alignmentRows) {
-
-        if (!iter.hasNext()) {
-            return;
-        }
-
-        Map<String, PairedAlignment> pairs = null;
-        if (pairAlignments) {
-            pairs = new HashMap<String, PairedAlignment>(1000);
-        }
-
-
-        // Strictly speaking we should loop discarding dupes, etc.
-        Alignment firstAlignment = iter.next();
-        if (pairAlignments && firstAlignment.isPaired() && firstAlignment.isProperPair() && firstAlignment.getMate().isMapped()) {
-            String readName = firstAlignment.getReadName();
-            PairedAlignment pair = new PairedAlignment(firstAlignment);
-            pairs.put(readName, pair);
-            firstAlignment = pair;
-        }
-
-        int start = firstAlignment.getStart();
-        int bucketCount = end - start + 1;
-
-        // Create buckets.  We use priority queues to keep the buckets sorted by alignment length.  However this
-        // is probably a needless complication,  any collection type would do.
-        PriorityQueue firstBucket = new PriorityQueue(5, lengthComparator);
-        firstBucket.add(firstAlignment);
-
-        // Use dense buckets for < 1,000,000 bp windows sparse otherwise
-
-        BucketCollection buckets;
-        if (bucketCount < 10000000) {
-            buckets = new DenseBucketCollection(bucketCount);
-        } else {
-            buckets = new SparseBucketCollection();
-        }
-        buckets.set(0, firstBucket);
-
-        int totalCount = 1;
-
-        //Allocate alignments to buckets based on position
-        while (iter.hasNext()) {
-
-            Alignment al = iter.next();
-            String readName = al.getReadName();
-
-            if (al.isMapped()) {
-
-                Alignment alignment = al;
-                if (pairAlignments && al.isPaired() && al.getMate().isMapped() && al.getChr().equals(al.getMate().getChr())) {
-
-                    PairedAlignment pair = pairs.get(readName);
-                    if (pair == null) {
-                        pair = new PairedAlignment(al);
-                        pairs.put(readName, pair);
-                        alignment = pair;
-                    } else {
-                        if (al.getChr().equals(pair.getChr())) {
-                            // Add second alignment to pair
-                            pair.setSecondAlignment(al);
-                            pairs.remove(readName);
-                            continue;
-                        }
-
-                    }
-                }
-
-
-                // We can get negative buckets if soft-clipping is on as the alignments are only approximately
-                // sorted.  Throw all alignments < start in the first bucket.
-                int bucketNumber = Math.max(0, alignment.getStart() - start);
-                if (bucketNumber < bucketCount) {
-                    PriorityQueue bucket = buckets.get(bucketNumber);
-                    if (bucket == null) {
-                        bucket = new PriorityQueue<Alignment>(5, lengthComparator);
-                        buckets.set(bucketNumber, bucket);
-                    }
-                    bucket.add(alignment);
-                    totalCount++;
-                } else {
-                    log.debug("Alignment out of bounds: " + alignment.getStart() + " (> " + end);
-                }
-
-
-            }
-        }
-
-        buckets.finishedAdding();
-
-        // Allocate alignments to rows
-        long t0 = System.currentTimeMillis();
-        int allocatedCount = 0;
-        int nextStart = start;
-        Row currentRow = new Row();
-        List<Integer> emptyBuckets = new ArrayList<Integer>(100);
-        while (allocatedCount < totalCount) { // && alignmentRows.size() < maxLevels) {
-
-            // Loop through alignments until we reach the end of the interval
-            while (nextStart <= end) {
-                PriorityQueue<Alignment> bucket;
-
-                // Advance to next occupied bucket
-                int bucketNumber = nextStart - start;
-                bucket = buckets.getNextBucket(bucketNumber, emptyBuckets);
-
-                // Pull the next alignment out of the bucket and add to the current row
-                if (bucket == null) {
-                    break;
-                } else {
-                    Alignment alignment = bucket.remove();
-                    currentRow.addAlignment(alignment);
-                    nextStart = currentRow.getLastEnd() + MIN_ALIGNMENT_SPACING;
-                    allocatedCount++;
-                }
-
-            }
-
-            // We've reached the end of the interval,  start a new row
-            if (currentRow.alignments.size() > 0) {
-                alignmentRows.add(currentRow);
-            }
-
-            // If we have more than 20 empty buckets remove them.  This has no affect on the "dense" implementation,
-            // they are removed on the fly, but is needed for the sparse implementation
-            buckets.removeBuckets(emptyBuckets);
-            emptyBuckets.clear();
-
-            // We need to keep all the rows,  rows do not == coverage  (rows can be partially empty)
-//            if (alignmentRows.size() >= maxLevels) {
-//                currentRow = null;
-//                break;
-//            }
-
-            currentRow = new Row();
-            nextStart = start;
-        }
-        if (log.isDebugEnabled()) {
-            long dt = System.currentTimeMillis() - t0;
-            log.debug("Packed alignments in " + dt);
-        }
-
-        // Add the last row
-        if (currentRow != null && currentRow.alignments.size() > 0) {
-            alignmentRows.add(currentRow);
-        }
-
-    }
-
-
     static interface BucketCollection {
 
+        Range getRange();
+
         void set(int idx, PriorityQueue<Alignment> bucket);
 
         PriorityQueue<Alignment> get(int idx);
@@ -324,6 +360,7 @@ public class AlignmentPacker {
 
         void finishedAdding();
 
+        int getBucketCount();
     }
 
     /**
@@ -332,12 +369,13 @@ public class AlignmentPacker {
      */
     static class DenseBucketCollection implements BucketCollection {
 
+        Range range;
         int lastBucketNumber = -1;
-
         final PriorityQueue[] bucketArray;
 
-        DenseBucketCollection(int bucketCount) {
-            bucketArray = new PriorityQueue[bucketCount];
+        DenseBucketCollection(int bucketCount, Range range) {
+            this.bucketArray = new PriorityQueue[bucketCount];
+            this.range = range;
         }
 
         public void set(int idx, PriorityQueue<Alignment> bucket) {
@@ -348,6 +386,13 @@ public class AlignmentPacker {
             return bucketArray[idx];
         }
 
+        public int getBucketCount() {
+            return this.bucketArray.length;
+        }
+
+        public Range getRange() {
+            return range;
+        }
 
         /**
          * Return the next occupied bucket after bucketNumber
@@ -364,6 +409,11 @@ public class AlignmentPacker {
 
             PriorityQueue<Alignment> bucket = null;
             while (bucketNumber < bucketArray.length) {
+
+                if (bucketNumber < 0) {
+                    System.out.println();
+                }
+
                 bucket = bucketArray[bucketNumber];
                 if (bucket != null) {
                     if (bucket.isEmpty()) {
@@ -394,12 +444,14 @@ public class AlignmentPacker {
      */
     static class SparseBucketCollection implements BucketCollection {
 
+        Range range;
         boolean finished = false;
         List<Integer> keys;
         final HashMap<Integer, PriorityQueue<Alignment>> buckets;
 
-        SparseBucketCollection() {
-            buckets = new HashMap(1000);
+        SparseBucketCollection(Range range) {
+            this.range = range;
+            this.buckets = new HashMap(1000);
         }
 
         public void set(int idx, PriorityQueue<Alignment> bucket) {
@@ -413,6 +465,10 @@ public class AlignmentPacker {
             return buckets.get(idx);
         }
 
+        public Range getRange() {
+            return range;
+        }
+
         /**
          * Return the next occupied bucket at or after after bucketNumber.
          *
@@ -471,6 +527,10 @@ public class AlignmentPacker {
             keys = new ArrayList<Integer>(buckets.keySet());
             Collections.sort(keys);
         }
+
+        public int getBucketCount() {
+            return Integer.MAX_VALUE;
+        }
     }
 
     private class PairOrientationComparator implements Comparator<String> {
