@@ -1,17 +1,31 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.sam;
 
 import org.apache.log4j.Logger;
-import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.Genome;
@@ -53,6 +67,7 @@ public class AlignmentRenderer implements FeatureRenderer {
     private static Color purple = new Color(118, 24, 220);
     private static Color deletionColor = Color.black;
     private static Color skippedColor = new Color(150, 184, 200);
+    private static Color unknownGapColor = new Color(0, 150, 0);
     public static Color grey1 = new Color(200, 200, 200);
 
     private static Stroke thickStroke = new BasicStroke(2.0f);
@@ -541,8 +556,6 @@ public class AlignmentRenderer implements FeatureRenderer {
 
         int lastBlockEnd = Integer.MIN_VALUE;
 
-        int blockNumber = -1;
-        char[] gapTypes = alignment.getGapTypes();
         boolean highZoom = locScale < 0.1251;
 
         // Get a graphics context for outlining reads
@@ -554,7 +567,7 @@ public class AlignmentRenderer implements FeatureRenderer {
         int y = (int) (rowRect.getY());
 
         for (AlignmentBlock aBlock : alignment.getAlignmentBlocks()) {
-            blockNumber++;
+
             int blockPixelStart = (int) ((aBlock.getStart() - origin) / locScale);
             int blockPixelWidth = (int) Math.ceil(aBlock.getLength() / locScale);
 
@@ -570,7 +583,7 @@ public class AlignmentRenderer implements FeatureRenderer {
                 Shape blockShape = null;
 
                 // If this is a terminal block draw the "arrow" to indicate strand position.  Otherwise draw a rectangle.
-                if ((aBlock == terminalBlock) && blockPixelWidth > 10)
+                if ((aBlock == terminalBlock) && blockPixelWidth > 10) {
                     if (h > 10) {
 
                         int arrowLength = Math.min(5, blockPixelWidth / 6);
@@ -614,7 +627,7 @@ public class AlignmentRenderer implements FeatureRenderer {
                             terminalGrpahics.drawLine(blockPixelStart + blockPixelWidth + 1, y, blockPixelStart + blockPixelWidth + 1, y + tH);
                         }
                     }
-                else {
+                } else {
                     // Not a terminal block, or too small for arrow
                     blockShape = new Rectangle(blockPixelStart, y, blockPixelWidth, h);
                 }
@@ -656,27 +669,53 @@ public class AlignmentRenderer implements FeatureRenderer {
             }
 
             // Draw connecting lines between blocks, if in view
-            if (lastBlockEnd > Integer.MIN_VALUE && blockPixelStart > rowRect.x) {
-                Graphics2D gLine;
-                Stroke stroke;
-                int gapIdx = blockNumber - 1;
-                Color gapLineColor = deletionColor;
-                if (gapTypes != null && gapIdx < gapTypes.length && gapTypes[gapIdx] == SAMAlignment.SKIPPED_REGION) {
-                    gLine = context.getGraphic2DForColor(skippedColor);
-                    stroke = gLine.getStroke();
-                } else {
-                    gLine = context.getGraphic2DForColor(gapLineColor);
-                    stroke = gLine.getStroke();
-                    //gLine.setStroke(dashedStroke);
-                    gLine.setStroke(thickStroke);
-                }
-
-                int startX = Math.max(rowRect.x, lastBlockEnd);
-                int endX = Math.min(rowRect.x + rowRect.width, blockPixelStart);
-
-                gLine.drawLine(startX, y + h / 2, endX, y + h / 2);
-                gLine.setStroke(stroke);
-            }
+//            if (lastBlockEnd > Integer.MIN_VALUE && blockPixelStart > rowRect.x) {
+//                Graphics2D gLine;
+//                Stroke stroke = null;
+//                Stroke gapStroke = null;
+//                int gapIdx = blockNumber - 1;
+//                Color gapLineColor = deletionColor;
+//
+//
+//                int type;
+//                if (gapTypes == null) {
+//                    type = SAMAlignment.DELETION;
+//                }
+//                else if(gapIdx >= gapTypes.length) {
+//                    type = SAMAlignment.UNKNOWN;  // This shouldn't happen
+//                }
+//                else {
+//                    type = gapTypes[gapIdx];
+//                }
+//
+//                switch(type) {
+//                    case SAMAlignment.UNKNOWN:
+//                        gapLineColor = unknownGapColor;
+//                        break;
+//                    case SAMAlignment.SKIPPED_REGION:
+//                        gapLineColor = skippedColor;
+//                        break;
+//                    default:
+//                        gapLineColor = deletionColor;
+//                        gapStroke = thickStroke;
+//                        break;
+//                }
+//
+//
+//                if (SAMAlignment.ZERO_GAP != type) {
+//                    gLine = context.getGraphic2DForColor(gapLineColor);
+//                    if (gapStroke != null) {
+//                        stroke = gLine.getStroke();
+//                        gLine.setStroke(thickStroke);
+//                    }
+//
+//                    int startX = Math.max(rowRect.x, lastBlockEnd);
+//                    int endX = Math.min(rowRect.x + rowRect.width, blockPixelStart);
+//                    gLine.drawLine(startX, y + h / 2, endX, y + h / 2);
+//                    if (stroke != null) gLine.setStroke(stroke);
+//                }
+//
+//            }
             lastBlockEnd = blockPixelStart + blockPixelWidth;
 
             // Next block cannot start before lastBlockEnd.  If its out of view we are done.
@@ -686,6 +725,61 @@ public class AlignmentRenderer implements FeatureRenderer {
 
         }
 
+        java.util.List<Gap> gaps = alignment.getGaps();
+        if (gaps != null) {
+            for (Gap gap : alignment.getGaps()) {
+
+                int gapStart = (int) ((gap.getStart() - origin) / locScale);
+                int gapWidth = (int) Math.ceil(gap.getnBases() / locScale);
+
+                // If block is out of view skip -- this is important in the case of PacBio and other platforms with very long reads
+                if (gapStart + gapWidth >= rowRect.x && gapStart <= rowRect.getMaxX()) {
+
+                    // Draw connecting lines between blocks, if in view
+                    Graphics2D gLine;
+                    Stroke stroke = null;
+                    Stroke gapStroke = null;
+                    Color gapLineColor = deletionColor;
+
+
+                    int type = gap.getType();
+
+                    switch (type) {
+                        case SAMAlignment.UNKNOWN:
+                            gapLineColor = unknownGapColor;
+                            break;
+                        case SAMAlignment.SKIPPED_REGION:
+                            gapLineColor = skippedColor;
+                            break;
+                        default:
+                            gapLineColor = deletionColor;
+                            gapStroke = thickStroke;
+                            break;
+                    }
+
+
+                    gLine = context.getGraphic2DForColor(gapLineColor);
+                    if (gapStroke != null) {
+                        stroke = gLine.getStroke();
+                        gLine.setStroke(thickStroke);
+                    }
+
+                    int startX = Math.max(rowRect.x, gapStart);
+                    int endX = Math.min(rowRect.x + rowRect.width, gapStart + gapWidth);
+                    gLine.drawLine(startX, y + h / 2, endX, y + h / 2);
+                    if (stroke != null) {
+                        gLine.setStroke(stroke);
+                    }
+                }
+
+                // Next block cannot start before lastBlockEnd.  If its out of view we are done.
+                if (gapStart + gapWidth > rowRect.getMaxX()) {
+                    break;
+                }
+
+            }
+        }
+
         // Render insertions if locScale < 1 bp / pixel (base level)
         if (locScale < 1) {
             drawInsertions(origin, rowRect, locScale, alignment, context, renderOptions);
@@ -1090,6 +1184,12 @@ public class AlignmentRenderer implements FeatureRenderer {
                     c = sampleColors.get(sample);
                 }
                 break;
+            case LIBRARY:
+                String library = alignment.getLibrary();
+                if (library != null) {
+                    c = sampleColors.get(library);
+                }
+                break;
             case TAG:
                 final String tag = renderOptions.getColorByTag();
                 if (tag != null) {
