@@ -38,6 +38,7 @@ import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.FeatureUtils;
 import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.Range;
+import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.ChromosomeNameComparator;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.lists.GeneList;
@@ -109,7 +110,8 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
     }
 
     public enum ColorOption {
-        INSERT_SIZE, READ_STRAND, FIRST_OF_PAIR_STRAND, PAIR_ORIENTATION, SAMPLE, READ_GROUP, BISULFITE, NOMESEQ,
+
+        INSERT_SIZE, READ_STRAND, FIRST_OF_PAIR_STRAND, PAIR_ORIENTATION, SAMPLE, READ_GROUP, LIBRARY, BISULFITE, NOMESEQ,
         TAG, NONE, UNEXPECTED_PAIR
     }
 
@@ -118,7 +120,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
     }
 
     public enum GroupOption {
-        STRAND, SAMPLE, READ_GROUP, FIRST_OF_PAIR_STRAND, TAG, PAIR_ORIENTATION, MATE_CHROMOSOME, NONE, SUPPLEMENTARY
+        STRAND, SAMPLE, READ_GROUP, LIBRARY, FIRST_OF_PAIR_STRAND, TAG, PAIR_ORIENTATION, MATE_CHROMOSOME, NONE, SUPPLEMENTARY
     }
 
     public enum BisulfiteContext {
@@ -237,9 +239,6 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
      */
     public void setExperimentType(ExperimentType type) {
         dataManager.setExperimentType(type);
-        if (spliceJunctionTrack != null) {
-            spliceJunctionTrack.setVisible(type != ExperimentType.BISULFITE);
-        }
     }
 
     public void setCoverageTrack(CoverageTrack coverageTrack) {
@@ -250,7 +249,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
     @Override
     public void setVisible(boolean visible) {
         super.setVisible(visible);
-        if(dataManager != null) dataManager.setShowAlignments(visible);
+        if (dataManager != null) dataManager.setShowAlignments(visible);
     }
 
     @XmlElement(name = RenderOptions.NAME)
@@ -321,8 +320,8 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
     }
 
     @Override
-    public void load(RenderContext context) {
-        dataManager.load(context, renderOptions, true);
+    public void load(ReferenceFrame referenceFrame) {
+        dataManager.load(referenceFrame, renderOptions, true);
     }
 
     public void render(RenderContext context, Rectangle rect) {
@@ -473,14 +472,15 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
      * Visually regroup alignments by the provided {@code GroupOption}.
      *
      * @param option
-     * @param referenceFrames
      * @see AlignmentDataManager#packAlignments
      */
-    public void groupAlignments(GroupOption option, List<ReferenceFrame> referenceFrames) {
-        if (renderOptions.groupByOption != option) {
-            renderOptions.groupByOption = (option == GroupOption.NONE ? null : option);
-            dataManager.packAlignments(renderOptions);
+    public void groupAlignments(GroupOption option, String tag) {
+        if (tag != null) {
+            renderOptions.setGroupByTag(tag);
         }
+        renderOptions.groupByOption = (option == GroupOption.NONE ? null : option);
+        dataManager.packAlignments(renderOptions);
+
     }
 
     public void packAlignments() {
@@ -920,7 +920,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
     }
 
     public void clearCaches() {
-        dataManager.clear();
+        if(dataManager != null) dataManager.clear();
         if (spliceJunctionTrack != null) spliceJunctionTrack.clear();
     }
 
@@ -1440,7 +1440,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
             mi.addActionListener(new ActionListener() {
 
                 public void actionPerformed(ActionEvent aEvt) {
-                    IGV.getInstance().groupAlignmentTracks(option);
+                    IGV.getInstance().groupAlignmentTracks(option, null);
                     refresh();
 
                 }
@@ -1459,6 +1459,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
             mappings.put("read strand", GroupOption.STRAND);
             mappings.put("first-in-pair strand", GroupOption.FIRST_OF_PAIR_STRAND);
             mappings.put("sample", GroupOption.SAMPLE);
+            mappings.put("library", GroupOption.LIBRARY);
             mappings.put("read group", GroupOption.READ_GROUP);
             mappings.put("chromosome of mate", GroupOption.MATE_CHROMOSOME);
             mappings.put("pair orientation", GroupOption.PAIR_ORIENTATION);
@@ -1478,7 +1479,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
                     String tag = MessageUtils.showInputDialog("Enter tag", renderOptions.getGroupByTag());
                     if (tag != null && tag.trim().length() > 0) {
                         renderOptions.setGroupByTag(tag);
-                        IGV.getInstance().groupAlignmentTracks(GroupOption.TAG);
+                        IGV.getInstance().groupAlignmentTracks(GroupOption.TAG, tag);
                         refresh();
                     }
 
@@ -1605,7 +1606,7 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
 
             mappings.put("read group", ColorOption.READ_GROUP);
             mappings.put("sample", ColorOption.SAMPLE);
-
+            mappings.put("library", ColorOption.LIBRARY);
 
             for (Map.Entry<String, ColorOption> el : mappings.entrySet()) {
                 JRadioButtonMenuItem mi = getColorMenuItem(el.getKey(), el.getValue());
@@ -2058,6 +2059,8 @@ public class AlignmentTrack extends AbstractTrack implements AlignmentTrackEvent
 
             item.addActionListener(new ActionListener() {
                 public void actionPerformed(ActionEvent aEvt) {
+                    String blatSeq = alignment.getReadStrand() == Strand.NEGATIVE ?
+                            SequenceTrack.getReverseComplement(seq) : seq;
                     BlatClient.doBlatQuery(seq);
                 }
             });
