@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.sam;
@@ -61,68 +75,78 @@ public class BisulfiteBaseInfo {
      * @param bisulfiteContext
      */
     public BisulfiteBaseInfo(byte[] inReference, Alignment baseAlignment, AlignmentBlock block, BisulfiteContext bisulfiteContext) {
+
         super();
 
         myContext = bisulfiteContext;
         byte[] inRead = block.getBases();
-        int alignmentLen = inRead.length;
+        if (inRead != null) {
+            int alignmentLen = inRead.length;
 
-        // We will only need reverse complement if the strand and paired end status don't match (2nd ends are G->A)
-        if (baseAlignment.isPaired()) {
-            flipRead = (baseAlignment.isPaired() && (baseAlignment.isNegativeStrand() ^ baseAlignment.isSecondOfPair()));
-        } else {
-            flipRead = baseAlignment.isNegativeStrand();
-        }
-        byte[] read = (flipRead) ? AlignmentUtils.reverseComplementCopy(inRead) : inRead;
-        byte[] reference = (flipRead && inReference != null) ? AlignmentUtils.reverseComplementCopy(inReference) : inReference;
+            // We will only need reverse complement if the strand and paired end status don't match (2nd ends are G->A)
+            if (baseAlignment.isPaired()) {
+                flipRead = (baseAlignment.isPaired() && (baseAlignment.isNegativeStrand() ^ baseAlignment.isSecondOfPair()));
+            } else {
+                flipRead = baseAlignment.isNegativeStrand();
+            }
+            byte[] read = (flipRead) ? AlignmentUtils.reverseComplementCopy(inRead) : inRead;
+            byte[] reference = (flipRead && inReference != null) ? AlignmentUtils.reverseComplementCopy(inReference) : inReference;
 
 
-        displayChars = new byte[alignmentLen];
-        displayStatus = new DisplayStatus[alignmentLen];
-        displayColors = new Color[alignmentLen];
+            displayChars = new byte[alignmentLen];
+            displayStatus = new DisplayStatus[alignmentLen];
+            displayColors = new Color[alignmentLen];
 
-        final int idxEnd = alignmentLen - 1;
-        for (int idxFw = 0; idxFw < alignmentLen; idxFw++) {
+            final int idxEnd = alignmentLen - 1;
+            for (int idxFw = 0; idxFw < alignmentLen; idxFw++) {
 
-            //// Everything comes in relative to the positive strand.
-            int idx = flipRead ? (idxEnd - idxFw) : idxFw;
+                //// Everything comes in relative to the positive strand.
+                int idx = flipRead ? (idxEnd - idxFw) : idxFw;
 
 
-            // Since we allow soft-cliping, the reference sequence can actually be shorter than the read.  Not sure
-            // what to do in this case,  just skip?
-            if (idx < 0 || idx > reference.length) continue;
+                // Since we allow soft-cliping, the reference sequence can actually be shorter than the read.  Not sure
+                // what to do in this case,  just skip?
+                if (idx < 0 || idx > reference.length) continue;
 
-            // The read base can be an equals sign, so change that to the actual ref base
-            byte refbase = reference[idx];
-            byte readbase = read[idx];
-            if (readbase == '=') readbase = refbase;
+                // The read base can be an equals sign, so change that to the actual ref base
+                byte refbase = reference[idx];
+                byte readbase = read[idx];
+                if (readbase == '=') readbase = refbase;
 
-            Color out = null;
-            boolean matchesContext = false;
+                // Force both bases to upper case
+                if (refbase > 90) {
+                    refbase = (byte) (refbase - 32);
+                }
+                if (readbase > 90) {
+                    readbase = (byte) (readbase - 32);
+                }
+
+                Color out = null;
+                boolean matchesContext = false;
 
 
-            // The logic is organized according to the reference base.
+                // The logic is organized according to the reference base.
 
-            switch (refbase) {
-                case 'T':
-                case 'A':
-                case 'G':
-                	if (AlignmentUtils.compareBases((byte) 'C', readbase)) out = METHYLATED_COLOR;
-                	else if (!AlignmentUtils.compareBases(readbase, refbase)) out = NONCYTOSINE_MISMATCH_COLOR;
-                    break;
-                case 'C':
-                    if (!AlignmentUtils.compareBases((byte) 'C', readbase) && !AlignmentUtils.compareBases((byte) 'T', readbase)) {
-                        out = CYTOSINE_MISMATCH_COLOR;
-                    } else {
-                    	// If we had information about whether this position was a SNP or not, we could
-                    	// show cytosines in any context when they are a SNP.
-                        BisulfiteContext matchingContext = contextIsMatching(reference, read, idx, bisulfiteContext);
-                        matchesContext = (matchingContext != null);
-                        if (matchesContext) {
-                            out = getContextColor(readbase, matchingContext);
+                switch (refbase) {
+                    case 'T':
+                    case 'A':
+                    case 'G':
+                        if (AlignmentUtils.compareBases((byte) 'C', readbase)) out = METHYLATED_COLOR;
+                        else if (!AlignmentUtils.compareBases(readbase, refbase)) out = NONCYTOSINE_MISMATCH_COLOR;
+                        break;
+                    case 'C':
+                        if (!AlignmentUtils.compareBases((byte) 'C', readbase) && !AlignmentUtils.compareBases((byte) 'T', readbase)) {
+                            out = CYTOSINE_MISMATCH_COLOR;
+                        } else {
+                            // If we had information about whether this position was a SNP or not, we could
+                            // show cytosines in any context when they are a SNP.
+                            BisulfiteContext matchingContext = contextIsMatching(reference, read, idx, bisulfiteContext);
+                            matchesContext = (matchingContext != null);
+                            if (matchesContext) {
+                                out = getContextColor(readbase, matchingContext);
+                            }
                         }
-                    }
-                    break;
+                        break;
 //                case 'G':
 //                    if (AlignmentUtils.compareBases((byte) 'A', readbase))
 //                    {
@@ -132,25 +156,25 @@ public class BisulfiteBaseInfo {
 //                    {
 //                    	out = NONCYTOSINE_MISMATCH_COLOR;
 //                    }
-            }
-
-            // Remember, the output should be relative to the FW strand (use idxFw)
-            this.displayColors[idxFw] = out;
-            if (out == null) {
-                this.displayStatus[idxFw] = DisplayStatus.NOTHING;
-            } else {
-                if (matchesContext) {
-                    // Display the color
-                    this.displayStatus[idxFw] = DisplayStatus.COLOR;
-                } else {
-                    // Display the character
-                    this.displayStatus[idxFw] = DisplayStatus.CHARACTER;
-                    this.displayChars[idxFw] = 'X';
                 }
-            }
-//			System.err.printf("\tSeting displayStatus[%d] = %s\n", idx, displayStatus[idx]);
-        }
 
+                // Remember, the output should be relative to the FW strand (use idxFw)
+                this.displayColors[idxFw] = out;
+                if (out == null) {
+                    this.displayStatus[idxFw] = DisplayStatus.NOTHING;
+                } else {
+                    if (matchesContext) {
+                        // Display the color
+                        this.displayStatus[idxFw] = DisplayStatus.COLOR;
+                    } else {
+                        // Display the character
+                        this.displayStatus[idxFw] = DisplayStatus.CHARACTER;
+                        this.displayChars[idxFw] = 'X';
+                    }
+                }
+//			System.err.printf("\tSeting displayStatus[%d] = %s\n", idx, displayStatus[idx]);
+            }
+        }
         //this.numDisplayStatus();
     }
 
@@ -179,12 +203,16 @@ public class BisulfiteBaseInfo {
      * @param idx
      * @param bisulfiteContext
      * @return Returns the context that matched (in the case of the base class, this is always the same
-     *         as the context passed in, derived classes might return a different context).
-     *         If we don't match, return null.
+     * as the context passed in, derived classes might return a different context).
+     * If we don't match, return null.
      */
     protected BisulfiteContext contextIsMatching(byte[] reference, byte[] read, int idx,
                                                  BisulfiteContext bisulfiteContext) {
 
+        if (BisulfiteContext.NONE == bisulfiteContext) {
+            return bisulfiteContext;
+        }
+
         // Get the context and see if it matches our desired context.
         byte[] preContext = AlignmentTrack.getBisulfiteContextPreContext(bisulfiteContext);
         byte[] postContext = AlignmentTrack.getBisulfiteContextPostContext(bisulfiteContext);
@@ -282,8 +310,8 @@ public class BisulfiteBaseInfo {
     /**
      * @param item
      * @return 0 if the cytosine context is not symmetric, else the number of
-     *         base pairs to shift the position by (caller must be careful to shift
-     *         relative to the strand the cytosine is on).
+     * base pairs to shift the position by (caller must be careful to shift
+     * relative to the strand the cytosine is on).
      */
     protected double getBisulfiteSymmetricCytosineShift(BisulfiteContext item) {
         double out = 0.0;
