@@ -69,7 +69,9 @@ import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
+import java.text.DecimalFormat;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 
@@ -77,10 +79,12 @@ import java.util.List;
  * @author jrobinso
  */
 @XmlType(factoryMethod = "getNextTrack")
-public class CoverageTrack extends AbstractTrack {
+
+public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
     private static Logger log = Logger.getLogger(CoverageTrack.class);
     public static final int TEN_MB = 10000000;
+    static DecimalFormat locationFormatter = new DecimalFormat();
 
     char[] nucleotides = {'a', 'c', 'g', 't', 'n'};
     public static Color lightBlue = new Color(0, 0, 150);
@@ -116,6 +120,12 @@ public class CoverageTrack extends AbstractTrack {
 
     private AlignmentTrack.RenderOptions renderOptions = null;
 
+    @SubtlyImportant
+    public CoverageTrack() {
+
+    }
+
+
     /**
      * Copy constructor.  Used for Sashimi plot.
      *
@@ -200,8 +210,8 @@ public class CoverageTrack extends AbstractTrack {
      */
     @Subscribe
     public void receiveDataLoaded(DataLoadedEvent e) {
-        ReferenceFrame frame = e.context.getReferenceFrame();
-        rescale(frame);
+        ReferenceFrame frame = e.getReferenceFrame();
+        //rescale(frame);
         frame.getEventBus().post(new ViewChange.Result());
     }
 
@@ -233,6 +243,7 @@ public class CoverageTrack extends AbstractTrack {
         }
     }
 
+
     public void render(RenderContext context, Rectangle rect) {
 
         if (context.getScale() > dataManager.getMinVisibleScale() && dataSource == null) {
@@ -243,38 +254,20 @@ public class CoverageTrack extends AbstractTrack {
         }
 
 
-        overlay(context, rect);
+        drawData(context, rect);
 
         drawBorder(context, rect);
 
-        // TODO -- What is this all about ??? JTR
-        List<LocusScore> scores = getSummaryScores(context);
-        if (scores != null) {
-            dataSourceRenderer.renderBorder(this, context, rect);
-        }
-
         if (dataSourceRenderer != null) {
+            dataSourceRenderer.renderBorder(this, context, rect);
             dataSourceRenderer.renderAxis(this, context, rect);
-        }
-        else {
+        } else {
             DataRenderer.drawScale(this.getDataRange(), context, rect);
         }
     }
 
 
-    private List<LocusScore> getSummaryScores(RenderContext context) {
-        List<LocusScore> scores = null;
-        if (dataSource != null) {
-            String chr = context.getChr();
-            int start = (int) context.getOrigin();
-            int end = (int) context.getEndLocation();
-            int zoom = context.getZoom();
-            scores = dataSource.getSummaryScoresForRange(chr, start, end, zoom);
-        }
-        return scores;
-    }
-
-    public void overlay(RenderContext context, Rectangle rect) {
+    public void drawData(RenderContext context, Rectangle rect) {
 
         float maxRange = PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
         float minVisibleScale = (maxRange * 1000) / 700;
@@ -283,26 +276,95 @@ public class CoverageTrack extends AbstractTrack {
             //Show coverage calculated from intervals if zoomed in enough
             AlignmentInterval interval = null;
             if (dataManager != null) {
-                dataManager.load(context, renderOptions, true);
+                dataManager.load(context.getReferenceFrame(), renderOptions, true);
                 interval = dataManager.getLoadedInterval(context.getReferenceFrame().getCurrentRange());
             }
             if (interval != null) {
                 if (interval.contains(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation())) {
-                    if (autoScale) rescale(context.getReferenceFrame());
+                    //if (autoScale) rescale(context.getReferenceFrame());
                     intervalRenderer.paint(context, rect, interval.getCounts());
                     return;
                 }
             }
         }
 
-        //Use precomputed scores, if available
-        List<LocusScore> scores = getSummaryScores(context);
+        //Not rendered yet.  Use precomputed scores, if available
+        List<LocusScore> scores = getInViewScores(context.getReferenceFrame());
         if (scores != null) {
             dataSourceRenderer.renderScores(this, scores, context, rect);
         }
 
     }
 
+
+    private List<LocusScore> getInViewScores(ReferenceFrame frame) {
+
+        List<LocusScore> inViewScores = null;
+
+        if (dataSource != null) {
+            String chr = frame.getChrName();
+            int start = (int) frame.getOrigin();
+            int end = (int) frame.getEnd();
+            int zoom = frame.getZoom();
+            inViewScores = dataSource.getSummaryScoresForRange(chr, start, end, zoom);
+
+            // Trim
+            // Trim scores
+            int startIdx = FeatureUtils.getIndexBefore(start, inViewScores);
+            int endIdx = inViewScores.size() - 1;   // Starting guess
+            int tmp = FeatureUtils.getIndexBefore(end, inViewScores);
+            for (int i = tmp; i < inViewScores.size(); i++) {
+                if (inViewScores.get(i).getStart() > end) {
+                    endIdx = i - 1;
+                    break;
+                }
+            }
+            endIdx = Math.max(startIdx + 1, endIdx);
+
+            return startIdx == 0 && endIdx == inViewScores.size() - 1 ?
+                    inViewScores :
+                    inViewScores.subList(startIdx, endIdx);
+        }
+        return inViewScores;
+    }
+
+
+    @Override
+    public Range getInViewRange(ReferenceFrame frame) {
+
+        if (dataManager == null || frame.getScale() > dataManager.getMinVisibleScale()) {
+
+            List<LocusScore> scores = getInViewScores(frame);
+            if (scores != null && scores.size() > 0) {
+                float min = scores.get(0).getScore();
+                float max = min;
+                for (int i = 1; i < scores.size(); i++) {
+                    LocusScore score = scores.get(i);
+                    float value = score.getScore();
+                    min = Math.min(value, min);
+                    max = Math.max(value, max);
+                }
+                return new Range(min, max);
+            } else {
+                return null;
+            }
+
+        } else {
+
+            AlignmentInterval interval = dataManager.getLoadedInterval(frame.getCurrentRange());
+            if (interval == null) return null;
+
+            int origin = (int) frame.getOrigin();
+            int end = (int) frame.getEnd() + 1;
+
+            int intervalMax = interval.getMaxCount(origin, end);
+
+            return new Range(0, Math.max(10, intervalMax));
+        }
+
+    }
+
+
     /**
      * Draw border and scale
      *
@@ -327,20 +389,27 @@ public class CoverageTrack extends AbstractTrack {
 
         float maxRange = PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
         float minVisibleScale = (maxRange * 1000) / 700;
+
+        StringBuffer buf = new StringBuffer();
+
+        if (!chr.equals("All")) {
+            String posString = chr + ":" + locationFormatter.format(Math.floor(position + 1));
+            buf.append(posString + "<br>");
+            buf.append("<hr>");
+        }
+
         if (frame.getScale() < minVisibleScale) {
             AlignmentInterval interval = dataManager.getLoadedInterval(frame.getCurrentRange());
-            if (interval == null) return null;
-
-            if (interval.contains(chr, (int) position, (int) position)) {
+            if (interval != null && interval.contains(chr, (int) position, (int) position)) {
                 AlignmentCounts counts = interval.getCounts();
                 if (counts != null) {
-                    return counts.getValueStringAt((int) position);
+                    buf.append(counts.getValueStringAt((int) position));
                 }
             }
         } else {
-            return getPrecomputedValueString(chr, position, frame);
+            buf.append(getPrecomputedValueString(chr, position, frame));
         }
-        return null;
+        return buf.toString();
     }
 
     private String getPrecomputedValueString(String chr, double position, ReferenceFrame frame) {
@@ -713,34 +782,20 @@ public class CoverageTrack extends AbstractTrack {
     @Override
     public IGVPopupMenu getPopupMenu(TrackClickEvent te) {
 
-        IGVPopupMenu popupMenu = new IGVPopupMenu();
-
-        JLabel popupTitle = new JLabel("  " + getName(), JLabel.CENTER);
-
-        Font newFont = popupMenu.getFont().deriveFont(Font.BOLD, 12);
-        popupTitle.setFont(newFont);
-        if (popupTitle != null) {
-            popupMenu.add(popupTitle);
-        }
-
-        popupMenu.addSeparator();
-
-        ArrayList<Track> tmp = new ArrayList();
+        Collection<Track> tmp = new ArrayList<Track>();
         tmp.add(this);
 
-        popupMenu.add(TrackMenuUtils.getChangeTrackHeightItem(tmp));
-        popupMenu.add(TrackMenuUtils.getTrackRenameItem(tmp));
-        addCopyDetailsItem(popupMenu, te);
-
-        addAutoscaleItem(popupMenu, te.getFrame());
-        addLogScaleItem(popupMenu);
-        dataRangeItem = addDataRangeItem(IGV.getMainFrame(), popupMenu, tmp);
+        IGVPopupMenu popupMenu = TrackMenuUtils.getPopupMenu(tmp, getName(), te);
 
+        popupMenu.addSeparator();
         this.addSnpTresholdItem(popupMenu);
 
         popupMenu.addSeparator();
         addLoadCoverageDataItem(popupMenu);
 
+        popupMenu.addSeparator();
+        addCopyDetailsItem(popupMenu, te);
+
         popupMenu.addSeparator();
         addShowItems(popupMenu);
 
@@ -831,7 +886,7 @@ public class CoverageTrack extends AbstractTrack {
 
     public void addShowItems(JPopupMenu menu) {
 
-        if(alignmentTrack != null) {
+        if (alignmentTrack != null) {
             final JMenuItem alignmentItem = new JCheckBoxMenuItem("Show Alignment Track");
             alignmentItem.setSelected(alignmentTrack.isVisible());
             alignmentItem.setEnabled(!alignmentTrack.isRemoved());
@@ -916,47 +971,6 @@ public class CoverageTrack extends AbstractTrack {
 
     }
 
-    public void addAutoscaleItem(JPopupMenu menu, final ReferenceFrame frame) {
-        // Change track height by attribute
-        final JMenuItem autoscaleItem = new JCheckBoxMenuItem("Autoscale");
-        autoscaleItem.setSelected(autoScale);
-        autoscaleItem.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-
-                autoScale = autoscaleItem.isSelected();
-                dataRangeItem.setEnabled(!autoScale);
-                if (autoScale) {
-                    rescale(frame);
-                }
-                IGV.getInstance().repaintDataPanels();
-
-            }
-        });
-
-        menu.add(autoscaleItem);
-    }
-
-    public void addLogScaleItem(JPopupMenu menu) {
-        // Change track height by attribute
-        final DataRange dataRange = getDataRange();
-        final JCheckBoxMenuItem logScaleItem = new JCheckBoxMenuItem("Log scale");
-        final boolean logScale = dataRange.getType() == DataRange.Type.LOG;
-        logScaleItem.setSelected(logScale);
-        logScaleItem.addActionListener(new ActionListener() {
-
-            public void actionPerformed(ActionEvent e) {
-
-                DataRange.Type scaleType = logScaleItem.isSelected() ?
-                        DataRange.Type.LOG :
-                        DataRange.Type.LINEAR;
-                dataRange.setType(scaleType);
-                IGV.getInstance().repaintDataPanels();
-            }
-        });
-
-        menu.add(logScaleItem);
-    }
 
     @SubtlyImportant
     private static CoverageTrack getNextTrack() {
