@@ -32,6 +32,7 @@ import org.broad.igv.feature.Strand;
 import org.broad.igv.track.WindowFunction;
 
 import java.awt.*;
+import java.util.List;
 
 /**
  * Some alignment formats are parsed as Features.
@@ -234,7 +235,8 @@ public class FeatureWrappedAlignment implements Alignment {
         return null;
     }
 
-    public char[] getGapTypes() {
+    @Override
+    public List<Gap> getGaps() {
         return null;
     }
 
