@@ -71,7 +71,17 @@ public class BAMHttpReader implements AlignmentReader<PicardAlignment> {
         this.locator = locator;
         this.url = new URL(locator.getPath());
         reader = getSamReader(locator, requireIndex);
+        header = reader.getFileHeader();
+        validateSequenceLengths(header);
+    }
 
+    private void validateSequenceLengths(SAMFileHeader header) {
+        SAMSequenceDictionary dict = header.getSequenceDictionary();
+        for (SAMSequenceRecord seq : dict.getSequences()) {
+            if(seq.getSequenceLength() > 536870911) {
+                throw new RuntimeException("Sequence lengths > 2^29-1 are not supported");
+            }
+        }
     }
 
     public SamReader getSamReader(ResourceLocator locator, boolean requireIndex) throws IOException {
@@ -166,12 +176,10 @@ public class BAMHttpReader implements AlignmentReader<PicardAlignment> {
 
         // Strip parameters
 
-
+        pathsTried.add(indexPath);
         if (HttpUtils.getInstance().resourceAvailable(new URL(indexPath))) {
             return IGVSeekableStreamFactory.getInstance().getStreamFor(new URL(indexPath));
         } else {
-
-
             if (indexPath.contains(".bam.bai")) {
                 indexPath = indexPath.replaceFirst(".bam.bai", ".bai");
                 pathsTried.add(indexPath);
@@ -191,7 +199,7 @@ public class BAMHttpReader implements AlignmentReader<PicardAlignment> {
 
         String msg = "Index file not found.  Tried ";
         for (String path : pathsTried) {
-            msg += "<br>" + indexPath;
+            msg += "<br>" + path;
         }
         throw new DataLoadException(msg, indexPath);
 
