@@ -247,6 +247,7 @@ public class IGVSessionReader implements SessionReader {
         DESCRIPTION("description"),
         TYPE("type"),
         COVERAGE("coverage"),
+        MAPPING("mapping"),
         TRACK_LINE("trackLine"),
 
         CHR("chr"),
@@ -397,7 +398,7 @@ public class IGVSessionReader implements SessionReader {
                 if (!genomeId.equals(GenomeManager.getInstance().getGenomeId())) {
                     String genomePath = genomeId;
                     if (!ParsingUtils.pathExists(genomePath)) {
-                        genomePath = FileUtils.getAbsolutePath(session.getPath(), genomeId);
+                        genomePath = getAbsolutePath(genomeId, rootPath, session.getPath());
                     }
                     if (ParsingUtils.pathExists(genomePath)) {
                         try {
@@ -705,6 +706,7 @@ public class IGVSessionReader implements SessionReader {
         String description = getAttribute(element, SessionAttribute.DESCRIPTION.getText());
         String type = getAttribute(element, SessionAttribute.TYPE.getText());
         String coverage = getAttribute(element, SessionAttribute.COVERAGE.getText());
+        String mapping = getAttribute(element, SessionAttribute.MAPPING.getText());
         String trackLine = getAttribute(element, SessionAttribute.TRACK_LINE.getText());
         String colorString = getAttribute(element, SessionAttribute.COLOR.getText());
         String index = getAttribute(element, SessionAttribute.INDEX.getText());
@@ -729,7 +731,8 @@ public class IGVSessionReader implements SessionReader {
             return;
         }
 
-        String absolutePath = getAbsolutePath(path, rootPath, alternateRootPath);
+        String absolutePath = "ga4gh".equals(type) ? path :
+                getAbsolutePath(path, rootPath, alternateRootPath);
 
         fullToRelPathMap.put(absolutePath, path);
 
@@ -738,10 +741,14 @@ public class IGVSessionReader implements SessionReader {
         if (index != null) resourceLocator.setIndexPath(index);
 
         if (coverage != null) {
-            String absoluteCoveragePath = getAbsolutePath(coverage, rootPath, alternateRootPath);
+            String absoluteCoveragePath = coverage.equals(".") ? coverage : getAbsolutePath(coverage, rootPath, alternateRootPath);
             resourceLocator.setCoverage(absoluteCoveragePath);
         }
 
+        if (mapping != null) {
+            String absoluteMappingPath = mapping.equals(".") ? mapping : getAbsolutePath(mapping, rootPath, alternateRootPath);
+            resourceLocator.setMappingPath(absoluteMappingPath);
+        }
 
         String url = getAttribute(element, SessionAttribute.URL.getText());
         if (url == null) {
