@@ -148,11 +148,11 @@ public abstract class AbstractTrack implements Track {
 
     @XmlJavaTypeAdapter(SessionXmlAdapters.Color.class)
     @XmlAttribute(name = "color")
-    private Color posColor = Color.blue.darker();
+    protected Color posColor = Color.blue.darker();
 
     @XmlJavaTypeAdapter(SessionXmlAdapters.Color.class)
     @XmlAttribute
-    private Color altColor = posColor;
+    protected Color altColor = posColor;
 
     @XmlAttribute(name = "featureVisibilityWindow")
     protected int visibilityWindow = -1;
@@ -167,7 +167,7 @@ public abstract class AbstractTrack implements Track {
     protected DataRange dataRange;
 
     @SubtlyImportant
-    private AbstractTrack() {
+    protected AbstractTrack() {
     }
 
     public AbstractTrack(
@@ -251,7 +251,7 @@ public abstract class AbstractTrack implements Track {
     }
 
     @Override
-    public void load(RenderContext context) {
+    public void load(ReferenceFrame referenceFrame) {
         // No-op, to be overriden by subclasses
     }
 
@@ -709,6 +709,9 @@ public abstract class AbstractTrack implements Track {
         }
         if (properties.getRendererClass() != null) {
             setRendererClass(properties.getRendererClass());
+            if(properties.getRendererClass() == PointsRenderer.class) {
+                setWindowFunction(WindowFunction.none);
+            }
         }
         if (properties.getWindowingFunction() != null) {
             setWindowFunction(properties.getWindowingFunction());
@@ -755,11 +758,13 @@ public abstract class AbstractTrack implements Track {
      * @return
      */
     public ContinuousColorScale getColorScale() {
+
         if (colorScale == null) {
 
             if (IGV.hasInstance()) {
                 ContinuousColorScale defaultScale = IGV.getInstance().getSession().getColorScale(trackType);
                 if (defaultScale != null) {
+                    colorScale = defaultScale;
                     return defaultScale;
                 }
             }
@@ -962,7 +967,15 @@ public abstract class AbstractTrack implements Track {
 
 
     public String getNameValueString(int y) {
-        return getName();
+
+        StringBuffer buffer = new StringBuffer();
+        buffer.append("<html>" + getName());
+
+        if(resourceLocator != null && resourceLocator.getPath() != null) {
+            buffer.append("<br>" + this.resourceLocator.getPath());
+        }
+
+        return buffer.toString();
     }
 
     /**
