@@ -55,8 +55,8 @@ public class CNFreqTrack extends AbstractTrack {
 
         float nSamples = data.getNumberOfSamples();
         this.setDataRange(new DataRange(-nSamples, 0, nSamples));
-        this.setColor(Color.red);
-        this.setAltColor(Color.blue);
+        this.posColor = Color.red;
+        this.altColor = Color.blue;
 
         renderer = new BarChartRenderer();
 
@@ -115,7 +115,7 @@ public class CNFreqTrack extends AbstractTrack {
         IGVPopupMenu menu = new IGVPopupMenu();
 
         List<Track> selfAsList = Arrays.asList((Track) this);
-        TrackMenuUtils.addSharedItems(menu, selfAsList, false);
+        TrackMenuUtils.addSharedItems(menu, selfAsList, false, false);
 
         return menu;
     }
