@@ -38,6 +38,7 @@ import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.FeatureUtils;
+import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
@@ -54,8 +55,7 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlType;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 import java.awt.*;
-import java.util.Collection;
-import java.util.HashMap;
+import java.util.*;
 import java.util.List;
 
 /**
@@ -64,7 +64,7 @@ import java.util.List;
  * @author jrobinso
  */
 @XmlType(factoryMethod = "getNextTrack")
-public abstract class DataTrack extends AbstractTrack {
+public abstract class DataTrack extends AbstractTrack implements ScalableTrack {
 
     private static Logger log = Logger.getLogger(DataTrack.class);
 
@@ -87,7 +87,7 @@ public abstract class DataTrack extends AbstractTrack {
             return;
         }
 
-        List<LocusScore> inViewScores = getInViewScores(context, rect);
+        List<LocusScore> inViewScores = getInViewScores(context.getReferenceFrame());
 
         if ((inViewScores == null || inViewScores.size() == 0) && Globals.CHR_ALL.equals(context.getChr())) {
             Graphics2D g = context.getGraphic2DForColor(Color.gray);
@@ -100,8 +100,13 @@ public abstract class DataTrack extends AbstractTrack {
 
 
     public void overlay(RenderContext context, Rectangle rect) {
-        List<LocusScore> inViewScores = getInViewScores(context, rect);
-        if (inViewScores != null) {
+
+        List<LocusScore> inViewScores = getInViewScores(context.getReferenceFrame());
+
+        if ((inViewScores == null || inViewScores.size() == 0) && Globals.CHR_ALL.equals(context.getChr())) {
+            Graphics2D g = context.getGraphic2DForColor(Color.gray);
+            GraphicUtils.drawCenteredText("Data not available for whole genome view; select chromosome to see data", rect, g);
+        } else if (inViewScores != null) {
             synchronized (inViewScores) {
                 getRenderer().renderScores(this, inViewScores, context, rect);
             }
@@ -110,71 +115,85 @@ public abstract class DataTrack extends AbstractTrack {
     }
 
 
-    public List<LocusScore> getInViewScores(RenderContext context, Rectangle rect) {
-        String chr = context.getChr();
-        int start = (int) context.getOrigin();
-        int end = (int) context.getEndLocation() + 1;
-        int zoom = context.getZoom();
+    public List<LocusScore> getInViewScores(ReferenceFrame referenceFrame) {
+
+        String chr = referenceFrame.getChrName();
+        int start = (int) referenceFrame.getOrigin();
+        int end = (int) referenceFrame.getEnd() + 1;
+        int zoom = referenceFrame.getZoom();
 
         List<LocusScore> inViewScores = null;
 
-        LoadedDataInterval interval = loadedIntervalCache.get(context.getReferenceFrame().getName());
+        LoadedDataInterval interval = loadedIntervalCache.get(referenceFrame.getName());
         if (interval != null && interval.contains(chr, start, end, zoom)) {
             inViewScores = interval.getScores();
         } else {
-            inViewScores = loadScores(context);
+            inViewScores = loadScores(referenceFrame);
         }
 
+        // Trim scores
+        int startIdx = FeatureUtils.getIndexBefore(start, inViewScores);
+        int endIdx = inViewScores.size();   // Starting guess
+        int tmp = FeatureUtils.getIndexBefore(end, inViewScores);
 
-        //Not all data sources support whole genome views, tell user if CHR_ALL not available
-        if ((inViewScores == null || inViewScores.size() == 0) && Globals.CHR_ALL.equals(chr)) {
-            Graphics2D g = context.getGraphic2DForColor(Color.gray);
-            GraphicUtils.drawCenteredText("Data not available for whole genome view; select chromosome to see data", rect, g);
-        } else {
-            if (autoScale && !FrameManager.isGeneListMode()) {
+        if (tmp < 0)
+            return Collections.EMPTY_LIST;
 
-                InViewInterval inter = computeScale(start, end, inViewScores);
-                if (inter.endIdx > inter.startIdx) {
-                    inViewScores = inViewScores.subList(inter.startIdx, inter.endIdx);
-
-                    DataRange dr = getDataRange();
-                    float min = Math.min(0, inter.dataMin);
-                    float base = Math.max(min, dr.getBaseline());
-                    float max = inter.dataMax;
-                    // Pathological case where min ~= max  (no data in view)
-                    if (max - min <= (2 * Float.MIN_VALUE)) {
-                        max = min + 1;
-                    }
-
-                    DataRange newDR = new DataRange(min, base, max, dr.isDrawBaseline());
-                    newDR.setType(dr.getType());
-                    setDataRange(newDR);
+        else {
+            for (int i = tmp; i < inViewScores.size(); i++) {
+                if (inViewScores.get(i).getStart() > end) {
+                    endIdx = i+1;
+                    break;
                 }
-
             }
+            endIdx = Math.max(startIdx + 1, endIdx);
+
+            return startIdx == 0 && endIdx == inViewScores.size() - 1 ?
+                    inViewScores :
+                    inViewScores.subList(startIdx, endIdx);
         }
-        return inViewScores;
     }
 
-    @Override
-    public synchronized void load(RenderContext context) {
+    public Range getInViewRange(ReferenceFrame referenceFrame) {
 
-        String chr = context.getChr();
-        int start = (int) context.getOrigin();
-        int end = (int) context.getEndLocation() + 1;
-        int zoom = context.getZoom();
-        LoadedDataInterval interval = loadedIntervalCache.get(context.getReferenceFrame().getName());
+        List<LocusScore> scores = getInViewScores(referenceFrame);
+        if (scores.size() > 0) {
+            float min = Float.MAX_VALUE;
+            float max = -Float.MAX_VALUE;
+            for (LocusScore score : scores) {
+                float value = score.getScore();
+                if (!Float.isNaN(value)) {
+                    min = Math.min(value, min);
+                    max = Math.max(value, max);
+                }
+            }
+            return new Range(min, max);
+        } else {
+            return null;
+        }
+
+    }
+
+    public synchronized void load(ReferenceFrame referenceFrame) {
+
+        String chr = referenceFrame.getChrName();
+        int start = (int) referenceFrame.getOrigin();
+        int end = (int) referenceFrame.getEnd() + 1;
+        int zoom = referenceFrame.getZoom();
+
+
+        LoadedDataInterval interval = loadedIntervalCache.get(referenceFrame.getName());
         if (interval == null || !interval.contains(chr, start, end, zoom)) {
-            loadScores(context);
+            loadScores(referenceFrame);
         }
     }
 
-    public List<LocusScore> loadScores(final RenderContext context) {
+    public List<LocusScore> loadScores(final ReferenceFrame referenceFrame) {
 
-        String chr = context.getChr();
-        int start = (int) context.getOrigin();
-        int end = (int) context.getEndLocation() + 1;
-        int zoom = context.getZoom();
+        String chr = referenceFrame.getChrName();
+        int start = (int) referenceFrame.getOrigin();
+        int end = (int) referenceFrame.getEnd() + 1;
+        int zoom = referenceFrame.getZoom();
 
         try {
             featuresLoading = true;
@@ -195,7 +214,7 @@ public abstract class DataTrack extends AbstractTrack {
             int expandedEnd = Math.min(maxEnd, end + delta);
             List<LocusScore> inViewScores = getSummaryScores(queryChr, expandedStart, expandedEnd, zoom);
             LoadedDataInterval interval = new LoadedDataInterval(chr, start, end, zoom, inViewScores);
-            loadedIntervalCache.put(context.getReferenceFrame().getName(), interval);
+            loadedIntervalCache.put(referenceFrame.getName(), interval);
             return inViewScores;
 
         } finally {
@@ -279,39 +298,6 @@ public abstract class DataTrack extends AbstractTrack {
 
     abstract public List<LocusScore> getSummaryScores(String chr, int startLocation, int endLocation, int zoom);
 
-    public static InViewInterval computeScale(double origin, double end, List<LocusScore> scores) {
-
-        InViewInterval interval = new InViewInterval();
-
-        if (scores.size() == 1) {
-            interval.dataMax = Math.max(0, scores.get(0).getScore());
-            interval.dataMin = Math.min(0, scores.get(0).getScore());
-        } else {
-            interval.startIdx = 0;
-            interval.endIdx = scores.size();
-            for (int i = 1; i < scores.size(); i++) {
-                if (scores.get(i).getEnd() >= origin) {
-                    interval.startIdx = i - 1;
-                    break;
-                }
-            }
-
-            for (int i = interval.startIdx + 1; i < scores.size(); i++) {
-                LocusScore locusScore = scores.get(i);
-                float value = locusScore.getScore();
-                if (Float.isNaN(value)) value = 0;
-                interval.dataMax = Math.max(interval.dataMax, value);
-                interval.dataMin = Math.min(interval.dataMin, value);
-                if (locusScore.getStart() > end) {
-                    interval.endIdx = i;
-                    break;
-                }
-            }
-        }
-
-        return interval;
-    }
-
     /**
      * Get the score over the provided region for the given type. Different types
      * are processed differently. Results are cached according to the provided frameName,
@@ -447,13 +433,6 @@ public abstract class DataTrack extends AbstractTrack {
         return regionScore;
     }
 
-    public static class InViewInterval {
-        public int startIdx;
-        public int endIdx;
-        public float dataMax = 0;
-        public float dataMin = 0;
-    }
-
     @SubtlyImportant
     private static DataTrack getNextTrack() {
         return (DataTrack) IGVSessionReader.getNextTrack();
