@@ -35,6 +35,7 @@ import org.broad.igv.feature.*;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.renderer.*;
+import org.broad.igv.renderer.Renderer;
 import org.broad.igv.session.IGVSessionReader;
 import org.broad.igv.session.SubtlyImportant;
 import org.broad.igv.tools.FeatureSearcher;
@@ -42,6 +43,7 @@ import org.broad.igv.tools.motiffinder.MotifFinderSource;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.event.DataLoadedEvent;
+import org.broad.igv.ui.event.ViewChange;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.*;
@@ -108,7 +110,7 @@ public class FeatureTrack extends AbstractTrack {
      */
     protected Map<String, PackedFeatures<IGVFeature>> packedFeaturesMap = Collections.synchronizedMap(new HashMap<String, PackedFeatures<IGVFeature>>());
 
-    private FeatureRenderer renderer;
+    private Renderer renderer;
 
     private DataRenderer coverageRenderer;
 
@@ -141,6 +143,8 @@ public class FeatureTrack extends AbstractTrack {
     //With this set to false, it chooses depending on the source
     private boolean forceLoadSync = false;
 
+    String trackLine = null;
+
     // TODO -- there are WAY too many constructors for this class
 
     /**
@@ -245,7 +249,7 @@ public class FeatureTrack extends AbstractTrack {
             return 0;
         }
         int rowHeight = getDisplayMode() == DisplayMode.SQUISHED ? squishedRowHeight : expandedRowHeight;
-        int minHeight = rowHeight * Math.max(1, getNumberOfFeatureLevels());
+        int minHeight = margin + rowHeight * Math.max(1, getNumberOfFeatureLevels());
         return Math.max(minHeight, super.getHeight());
     }
 
@@ -271,7 +275,7 @@ public class FeatureTrack extends AbstractTrack {
 
     public void setRendererClass(Class rc) {
         try {
-            renderer = (FeatureRenderer) rc.newInstance();
+            renderer = (Renderer) rc.newInstance();
         } catch (Exception ex) {
             log.error("Error instatiating renderer ", ex);
         }
@@ -378,7 +382,7 @@ public class FeatureTrack extends AbstractTrack {
     }
 
 
-    public FeatureRenderer getRenderer() {
+    public Renderer getRenderer() {
         if (renderer == null) {
             setRendererClass(IGVFeatureRenderer.class);
         }
@@ -410,7 +414,7 @@ public class FeatureTrack extends AbstractTrack {
             for (Feature feature : allFeatures) {
                 if (feature != null && feature instanceof IGVFeature) {
                     if (!firstFeature) {
-                        buf.append("<br/>--------------<br/>");
+                        buf.append("<hr><br>");
                     }
 
                     IGVFeature igvFeature = (IGVFeature) feature;
@@ -495,7 +499,7 @@ public class FeatureTrack extends AbstractTrack {
      * @param frame
      * @return
      */
-    private List<Feature> getAllFeatureAt(double position, int y, ReferenceFrame frame) {
+    protected List<Feature> getAllFeatureAt(double position, int y, ReferenceFrame frame) {
         // Determine the level number (for expanded tracks)
         int featureRow = getFeatureRow(y);
         return getFeaturesAtPositionInFeatureRow(position, featureRow, frame);
@@ -508,18 +512,22 @@ public class FeatureTrack extends AbstractTrack {
      * @return
      */
     private int getFeatureRow(int y) {
-        // Determine the level number (for expanded tracks).
-        int featureRow = 0;
-        if (levelRects != null) {
-            for (int i = 0; i < levelRects.size(); i++) {
-                Rectangle r = levelRects.get(i);
-                if ((y >= r.y) && (y <= r.getMaxY())) {
-                    featureRow = i;
-                    break;
-                }
-            }
+
+        int rowHeight;
+        DisplayMode mode = getDisplayMode();
+        switch(mode) {
+            case SQUISHED:
+                rowHeight = getSquishedRowHeight();
+                break;
+            case EXPANDED:
+                rowHeight = getExpandedRowHeight();
+                break;
+            default:
+                rowHeight = getHeight();
         }
-        return featureRow;
+
+       return Math.max(0, Math.min(levelRects.size()-1, (int) ((y - this.getY() - this.margin)/ rowHeight)));
+
     }
 
     /**
@@ -658,20 +666,18 @@ public class FeatureTrack extends AbstractTrack {
         super.setDisplayMode(mode);
     }
 
-    @Override
-    public void load(RenderContext context) {
-        ReferenceFrame frame = context.getReferenceFrame();
+    public void load(ReferenceFrame frame) {
         PackedFeatures packedFeatures = packedFeaturesMap.get(frame.getName());
-        String chr = context.getChr();
-        int start = (int) context.getOrigin();
-        int end = (int) context.getEndLocation();
+        String chr = frame.getChrName();
+        int start = (int) frame.getOrigin();
+        int end = (int) frame.getEnd();
         if (packedFeatures == null || !packedFeatures.containsInterval(chr, start, end)) {
             try {
-                context.getReferenceFrame().getEventBus().unregister(FeatureTrack.this);
+                frame.getEventBus().unregister(FeatureTrack.this);
             } catch (IllegalArgumentException e) {
                 //Don't care
             }
-            loadFeatures(frame.getChrName(), (int) frame.getOrigin(), (int) frame.getEnd(), context);
+            loadFeatures(frame.getChrName(), (int) frame.getOrigin(), (int) frame.getEnd(), frame);
         }
     }
 
@@ -782,7 +788,7 @@ public class FeatureTrack extends AbstractTrack {
 
         //Attempt to load the relevant data. Note that there is no guarantee
         //the data will be loaded once preload exits, as loading may be asynchronous
-        load(context);
+        load(context.getReferenceFrame());
         PackedFeatures packedFeatures = packedFeaturesMap.get(context.getReferenceFrame().getName());
 
         if (packedFeatures == null || !packedFeatures.overlapsInterval(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation() + 1)) {
@@ -814,7 +820,7 @@ public class FeatureTrack extends AbstractTrack {
     protected void renderFeatureImpl(RenderContext context, Rectangle inputRect, PackedFeatures packedFeatures) {
 
 
-        FeatureRenderer renderer = getRenderer();
+        Renderer renderer = getRenderer();
         if (areFeaturesStacked()) {
             List<PackedFeatures.FeatureRow> rows = packedFeatures.getRows();
             if (rows != null && rows.size() > 0) {
@@ -825,11 +831,11 @@ public class FeatureTrack extends AbstractTrack {
                     levelRects.clear();
 
                     // Divide rectangle into equal height levels
-                    double h = inputRect.getHeight() / nLevels;
+                    double h = getDisplayMode() == DisplayMode.SQUISHED ? squishedRowHeight : expandedRowHeight;
                     Rectangle rect = new Rectangle(inputRect.x, inputRect.y, inputRect.width, (int) h);
                     int i = 0;
 
-                    renderer.reset();
+                    if(renderer instanceof FeatureRenderer) ((FeatureRenderer) renderer).reset();
                     for (PackedFeatures.FeatureRow row : rows) {
                         levelRects.add(new Rectangle(rect));
                         renderer.render(row.features, context, levelRects.get(i), this);
@@ -843,7 +849,7 @@ public class FeatureTrack extends AbstractTrack {
                 }
             }
         } else {
-            List<IGVFeature> features = packedFeatures.getFeatures();
+            List<Feature> features = packedFeatures.getFeatures();
             if (features != null) {
                 renderer.render(features, context, inputRect, this);
             }
@@ -859,7 +865,7 @@ public class FeatureTrack extends AbstractTrack {
      * @param start
      * @param end
      */
-    protected void loadFeatures(final String chr, final int start, final int end, final RenderContext context) {
+    protected void loadFeatures(final String chr, final int start, final int end, final ReferenceFrame referenceFrame) {
 
         boolean aSync = !forceLoadSync && !(source instanceof FeatureCollectionSource);
 
@@ -898,23 +904,23 @@ public class FeatureTrack extends AbstractTrack {
                         Iterator<Feature> iter = source.getFeatures(chr, expandedStart, expandedEnd);
                         if (iter == null) {
                             PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd);
-                            packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                            packedFeaturesMap.put(referenceFrame.getName(), pf);
                         } else {
                             //dhmay putting a switch in for different packing behavior in splice junction tracks.
                             //This should probably be switched somewhere else, but that would require a big refactor.
                             PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd, iter, getName());
-                            packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                            packedFeaturesMap.put(referenceFrame.getName(), pf);
                         }
                     }
 
                     //Now that features are loaded, we may need to repaint
                     //to accommodate.
-                    context.getReferenceFrame().getEventBus().post(new DataLoadedEvent(context));
+                    referenceFrame.getEventBus().post(new DataLoadedEvent(referenceFrame));
                 } catch (Exception e) {
                     // Mark the interval with an empty feature list to prevent an endless loop of load
                     // attempts.
                     PackedFeatures pf = new PackedFeatures(chr, start, end);
-                    packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                    packedFeaturesMap.put(referenceFrame.getName(), pf);
                     String msg = "Error loading features for interval: " + chr + ":" + start + "-" + end + " <br>" + e.toString();
                     MessageUtils.showMessage(msg);
                     log.error(msg, e);
@@ -929,7 +935,7 @@ public class FeatureTrack extends AbstractTrack {
         };
 
         if (aSync) {
-            context.getReferenceFrame().getEventBus().register(FeatureTrack.this);
+            referenceFrame.getEventBus().register(FeatureTrack.this);
             LongRunningTask.submit(runnable);
         } else {
             runnable.run();
@@ -954,8 +960,10 @@ public class FeatureTrack extends AbstractTrack {
             //don't want to layout for each one
             IGV.getInstance().layoutMainPanel();
         }
-        JComponent panel = event.context.getPanel();
-        if (panel != null) panel.repaint();
+        event.getReferenceFrame().getEventBus().post(new ViewChange.Result());
+        System.out.println("Data loaded");
+       // JComponent panel = event.context.getPanel();
+      //  if (panel != null) panel.repaint();
     }
 
     /**
@@ -1134,13 +1142,18 @@ public class FeatureTrack extends AbstractTrack {
 
     }
 
+
+    public void setTrackLine(String trackLine) {
+        this.trackLine = trackLine;
+    }
+
     /**
      * Return "track" line information for exporting features to a file.  Default is null, subclasses may override.
      *
      * @return
      */
     public String getExportTrackLine() {
-        return null;
+        return trackLine;
     }
 }
 
