@@ -47,6 +47,7 @@ public class RenderContextImpl implements RenderContext {
     private ReferenceFrame referenceFrame;
     private JComponent panel;
     private Rectangle visibleRect;
+    boolean merged;
 
 
     public RenderContextImpl(JComponent panel, Graphics2D graphics, ReferenceFrame referenceFrame, Rectangle visibleRect) {
@@ -62,7 +63,10 @@ public class RenderContextImpl implements RenderContext {
         Graphics2D g = graphicCacheByColor.get(color);
         if (g == null) {
             g = (Graphics2D) graphics.create();
-            g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+            if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.ENABLE_ANTIALISING)) {
+                g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+                g.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+            }
             graphicCacheByColor.put(color, g);
             g.setColor(color);
 
@@ -111,6 +115,15 @@ public class RenderContextImpl implements RenderContext {
         return referenceFrame;
     }
 
+    @Override
+    public boolean isMerged() {
+        return merged;
+    }
+
+    public void setMerged(boolean merged) {
+        this.merged = merged;
+    }
+
     public int bpToScreenPixel(double location) {
         final double scale = getScale();
         final double origin = getOrigin();
@@ -129,6 +142,8 @@ public class RenderContextImpl implements RenderContext {
         dispose();
     }
 
+
+
     public void dispose() {
         for (Graphics2D g : graphicCacheByColor.values()) {
             g.dispose();
