@@ -47,11 +47,17 @@ import org.broad.igv.dev.db.SQLCodecSource;
 import org.broad.igv.dev.db.SampleInfoSQLReader;
 import org.broad.igv.dev.db.SegmentedSQLReader;
 import org.broad.igv.exceptions.DataLoadException;
+import org.broad.igv.feature.basepair.BasePairTrack;
+import org.broad.igv.feature.BasePairFileUtils;
+import org.broad.igv.feature.ShapeFileUtils;
 import org.broad.igv.feature.CachingFeatureSource;
 import org.broad.igv.feature.GisticFileParser;
 import org.broad.igv.feature.MutationTrackLoader;
 import org.broad.igv.feature.bionano.SMAPParser;
+import org.broad.igv.feature.bionano.SMAPRenderer;
 import org.broad.igv.feature.dranger.DRangerParser;
+import org.broad.igv.feature.dsi.DSIRenderer;
+import org.broad.igv.feature.dsi.DSITrack;
 import org.broad.igv.feature.genome.*;
 import org.broad.igv.feature.tribble.CodecFactory;
 import org.broad.igv.feature.tribble.FeatureFileHeader;
@@ -79,6 +85,8 @@ import org.broad.igv.tdf.TDFReader;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.ConfirmDialog;
 import org.broad.igv.ui.util.MessageUtils;
+import org.broad.igv.ui.util.ConvertFileDialog;
+import org.broad.igv.ui.util.ConvertOptions;
 import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ParsingUtils;
@@ -88,9 +96,11 @@ import org.broad.igv.variant.util.PedigreeUtils;
 import htsjdk.tribble.AsciiFeatureCodec;
 import htsjdk.variant.vcf.VCFHeader;
 
+import java.awt.*;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.util.*;
+import java.util.List;
 
 /**
  * User: jrobinso
@@ -129,8 +139,6 @@ public class TrackLoader {
             LoadHandler handler = getTrackLoaderHandler(typeString);
             if (dbUrl != null) {
                 this.loadFromDatabase(locator, newTracks, genome);
-            } else if (CodecFactory.hasCodec(locator, genome) && !forceNotTribble(typeString)) {
-                loadTribbleFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".dbxml")) {
                 loadFromDBProfile(locator, newTracks);
             } else if (typeString.endsWith(".gmt")) {
@@ -168,12 +176,10 @@ public class TrackLoader {
                 loadRNAiHPScoreFile(locator);
             } else if (typeString.contains(".tabblastn") || typeString.endsWith(".orthologs")) {
                 loadSyntentyMapping(locator, newTracks);
-            } else if (typeString.endsWith(".sam") || typeString.endsWith(".bam") ||
-                    typeString.endsWith(".sam.list") || typeString.endsWith(".bam.list") ||
-                    typeString.endsWith(".aligned") || typeString.endsWith(".sai") ||
-                    typeString.endsWith(".bai") || typeString.equals("alist") ||
-                    typeString.equals(Ga4ghAPIHelper.RESOURCE_TYPE)) {
+            } else if (isAlignmentTrack(typeString)) {
                 loadAlignmentsTrack(locator, newTracks, genome);
+            } else if (typeString.endsWith(".shape") || typeString.endsWith(".map")) {
+                convertLoadShapeFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".wig") || typeString.endsWith(".bedgraph") || typeString.endsWith(".bdg") ||
                     typeString.endsWith("cpg.txt") || typeString.endsWith(".expr")) {
                 loadWigFile(locator, newTracks, genome);
@@ -202,6 +208,14 @@ public class TrackLoader {
             } else if (typeString.endsWith("mage-tab") || ExpressionFileParser.parsableMAGE_TAB(locator)) {
                 locator.setDescription("MAGE_TAB");
                 loadGctFile(locator, newTracks, genome);
+            } else if (typeString.endsWith(".db") || typeString.endsWith(".dbn")) {
+                convertLoadStructureFile(locator, newTracks, genome, "dotBracket");
+            } else if (typeString.endsWith(".ct")) {
+                convertLoadStructureFile(locator, newTracks, genome, "connectTable");
+            } else if (typeString.endsWith(".dp")) {
+                convertLoadStructureFile(locator, newTracks, genome, "pairingProb");
+            } else if (typeString.endsWith(".bp")) {
+                loadBasePairFile(locator, newTracks, genome);
             } else if (GWASParser.isGWASFile(typeString)) {
                 loadGWASFile(locator, newTracks, genome);
             } else if (GobyAlignmentQueryReader.supportsFileType(path)) {
@@ -211,6 +225,10 @@ public class TrackLoader {
                 loadListFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".smap")) {
                 loadSMAPFile(locator, newTracks, genome);
+            } else if (typeString.endsWith("dsi")) {
+                loadDSIFile(locator, newTracks, genome);
+            } else if (CodecFactory.hasCodec(locator, genome) && !forceNotTribble(typeString)) {
+                loadTribbleFile(locator, newTracks, genome);
             } else if (handler != null) {
                 //Custom loader specified
                 log.info(String.format("Loading %s with %s", path, handler));
@@ -256,11 +274,21 @@ public class TrackLoader {
 
     }
 
+    public static boolean isAlignmentTrack(String typeString) {
+        return typeString.endsWith(".sam") || typeString.endsWith(".bam") ||
+                typeString.endsWith(".sam.list") || typeString.endsWith(".bam.list") ||
+                typeString.endsWith(".aligned") || typeString.endsWith(".sai") ||
+                typeString.endsWith(".bai") || typeString.equals("alist") ||
+                typeString.equals(Ga4ghAPIHelper.RESOURCE_TYPE);
+    }
+
     private void loadSMAPFile(ResourceLocator locator, List<Track> newTracks, Genome genome) throws IOException {
 
         List<Feature> features = SMAPParser.parseFeatures(locator, genome);
         FeatureCollectionSource src = new FeatureCollectionSource(features, genome);
         FeatureTrack track = new FeatureTrack(locator, locator.getName(), src);
+        track.setRendererClass(SMAPRenderer.class);
+        track.setDisplayMode(Track.DisplayMode.EXPANDED);
         newTracks.add(track);
     }
 
@@ -376,6 +404,7 @@ public class TrackLoader {
         } else {
 
             TribbleFeatureSource tribbleFeatureSource = TribbleFeatureSource.getFeatureSource(locator, genome);
+
             FeatureSource src = GFFFeatureSource.isGFF(locator.getPath()) ?
                     new GFFFeatureSource(tribbleFeatureSource) : tribbleFeatureSource;
 
@@ -392,9 +421,10 @@ public class TrackLoader {
                     t.setTrackType(ffh.getTrackType());
                 }
                 if (ffh.getTrackProperties() != null) {
-                    t.setProperties(ffh.getTrackProperties());
+                    TrackProperties tp = ffh.getTrackProperties();
+                    t.setProperties(tp);
+                    t.setTrackLine(tp.getTrackLine());
                 }
-
                 if (ffh.getTrackType() == TrackType.REPMASK) {
                     t.setHeight(15);
                 }
@@ -406,6 +436,29 @@ public class TrackLoader {
         }
     }
 
+    private void loadDSIFile(ResourceLocator locator, List<Track> newTracks, Genome genome) throws IOException, TribbleIndexNotFoundException {
+
+        TribbleFeatureSource tribbleFeatureSource = TribbleFeatureSource.getFeatureSource(locator, genome);
+
+        // Create feature source and track
+        DSITrack t = new DSITrack(locator, tribbleFeatureSource);
+        t.setName(locator.getTrackName());
+        //t.setRendererClass(BasicTribbleRenderer.class);
+
+        // Set track properties from header
+        Object header = tribbleFeatureSource.getHeader();
+        if (header != null && header instanceof TrackProperties) {
+            TrackProperties tp = (TrackProperties) header;
+            t.setProperties(tp);
+            t.setTrackLine(tp.getTrackLine());
+        }
+
+        t.setRendererClass(DSIRenderer.class);
+
+        newTracks.add(t);
+    }
+
+
     /**
      * Load GWAS PLINK result file
      *
@@ -585,7 +638,7 @@ public class TrackLoader {
 
         final String path = locator.getPath();
         long size = FileUtils.getLength(path);
-        int maxSize = 50000000;  // 50 mb
+        int maxSize = 200000000;  // 200 mb
         if (path.endsWith(".gz") || path.endsWith(".bgz")) {
             maxSize /= 4;
         }
@@ -594,7 +647,7 @@ public class TrackLoader {
 
             String message = "The file " + path + " is large (" + (size / 1000000) + " mb).  It is recommended " +
                     "that large files be converted to the binary <i>.tdf</i> format using the IGVTools " +
-                    "<b>tile</b> command. Loading  unconverted ascii fies of this size can lead to poor " +
+                    "<b>toTDF</b> command. Loading  unconverted ascii fies of this size can lead to poor " +
                     "performance or unresponsiveness (freezing).  " +
                     "<br><br>IGVTools can be launched from the <b>Tools</b> menu or separately as a " +
                     "command line program. See the user guide for more details.<br><br>Click <b>Continue</b> " +
@@ -920,7 +973,7 @@ public class TrackLoader {
                     }
 
                 }
-                if (covPath != null) {
+                if (covPath != null && !covPath.equals(".")) {
                     if (FileUtils.resourceExists(covPath)) {
                         log.debug("Loading TDF for coverage: " + covPath);
                         try {
@@ -1105,14 +1158,28 @@ public class TrackLoader {
 
         // The "freq" track.  TODO - make this optional
         if ((ds.getType() == TrackType.COPY_NUMBER || ds.getType() == TrackType.CNV) &&
-                ds.getSampleNames().size() > 4) {
+                ds.getSampleNames().size() > 1) {
             FreqData fd = new FreqData(ds, genome);
             String freqTrackId = path;
             String freqTrackName = "CNV Summary";
             CNFreqTrack freqTrack = new CNFreqTrack(locator, freqTrackId, freqTrackName, fd);
+
+            if (props != null) {
+                freqTrack.setProperties(props);
+            }
+
             newTracks.add(freqTrack);
         }
 
+        ContinuousColorScale colorScale = null;
+        if (props != null) {
+            Color maxColor = props.getColor();
+            Color minColor = props.getAltColor();
+            if (maxColor != null && minColor != null) {
+                colorScale = PreferenceManager.getDefaultColorScale(minColor, Color.white, maxColor);
+            }
+        }
+
         for (String trackName : ds.getSampleNames()) {
             String trackId = path + "_" + trackName;
             SegmentedDataSource dataSource = new SegmentedDataSource(trackName, ds);
@@ -1123,6 +1190,9 @@ public class TrackLoader {
             if (props != null) {
                 track.setProperties(props);
             }
+            if (colorScale != null) {
+                track.setColorScale(colorScale);
+            }
 
             newTracks.add(track);
         }
@@ -1175,6 +1245,69 @@ public class TrackLoader {
         PedigreeUtils.parseTrioFile(locator.getPath());
     }
 
+    /**
+     * Convert an RNA chemical reactivity file (.shape, .map) into a .wig file
+     * and load.
+
+     */
+    private void convertLoadShapeFile(ResourceLocator locator,
+                                      List<Track> newTracks,
+                                      Genome genome) throws IOException {
+        String inPath = locator.getPath();
+        String fileName = locator.getFileName();
+        String outPath = inPath + ".wig";
+        String message = "The chemical reactivity file <br> &nbsp;&nbsp;" + fileName + "<br> needs to be converted to IGV chromosome <br>" +
+                         "coordinates and .wig format before loading. <br><br>Click <b>Continue</b> " +
+                         "to save converted file to <br> &nbsp;&nbsp;" + fileName+".wig" +
+                         "<br>and load with the selected options, or <b>Cancel</b> to skip this<br>file.";
+
+        ConvertOptions opts =  ConvertFileDialog.showConvertFileDialog(message);
+        if (opts.doConvert) {
+            ShapeFileUtils.shapeToWigFile(inPath, outPath, opts.chrom, opts.strand, opts.start);
+            loadWigFile(new ResourceLocator(outPath), newTracks, genome);
+        }
+    }
+
+    /**
+     * Convert various RNA structure formats to a more easily parseable format
+     * in genomic coordinates, then load converted file.
+
+     */
+    private void convertLoadStructureFile(ResourceLocator locator,
+                                          List<Track> newTracks,
+                                          Genome genome,
+                                          String fileType) throws IOException {
+        String inPath = locator.getPath();
+        String fileName = locator.getFileName();
+        String outPath = inPath + ".bp";
+
+        String message = "The RNA structure file <br> &nbsp;&nbsp;" + fileName + "<br> needs to be converted to IGV chromosome <br>" +
+                         "coordinates and .bp format before loading. <br><br>Click <b>Continue</b> " +
+                         "to save converted file to <br> &nbsp;&nbsp;" + fileName+".bp" +
+                         "<br>and load with the selected options, or <b>Cancel</b> to skip this<br>file.";
+
+        ConvertOptions opts =  ConvertFileDialog.showConvertFileDialog(message);
+
+        if (opts.doConvert){
+            if (fileType == "connectTable") {
+                BasePairFileUtils.connectTableToBasePairFile(inPath, outPath, opts.chrom, opts.strand, opts.start);
+            } else if (fileType == "pairingProb") {
+                BasePairFileUtils.pairingProbToBasePairFile(inPath, outPath, opts.chrom, opts.strand, opts.start);
+            } else if (fileType == "dotBracket") {
+                BasePairFileUtils.dotBracketToBasePairFile(inPath, outPath, opts.chrom, opts.strand, opts.start);
+            }
+            loadBasePairFile(new ResourceLocator(outPath), newTracks, genome);
+        }
+    }
+
+    private void loadBasePairFile(ResourceLocator locator,
+                                  List<Track> newTracks,
+                                  Genome genome) throws IOException {
+        String name = locator.getTrackName();
+        String path = locator.getPath();
+        String id = path + "_" + name;
+        newTracks.add(new BasePairTrack(locator, id, name, genome));
+    }
 
     public static boolean isIndexed(ResourceLocator locator, Genome genome) {
 
