@@ -76,13 +76,12 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
         boolean indexExists = FileUtils.resourceExists(idxPath);
 
         // Optionally let the user create an index.
-        final int tenMB = 10000000;
+        final int hundredMB = 100000000;
         final int oneGB = 1000000000;
         long size = FileUtils.getLength(locator.getPath());
-        final boolean indexRequired =
-                (VariantTrack.isVCF(locator.getTypeString()) && size > tenMB) || size > oneGB;
+        final boolean indexRequired =  size > oneGB;
         if (!Globals.isHeadless() && locator.isLocal() && !locator.getPath().endsWith(".gz") && !indexExists) {
-            if (size > tenMB) {
+            if (size > hundredMB) {
                 createIndex(locator, indexRequired);   // Note, might return null.
             }
         }
@@ -112,7 +111,8 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
         File newIdxFile = new File(locator.getPath() + ".idx");
         String messageText = "An index file for " + baseFile.getAbsolutePath() + " could not " +
                 "be located. An index is " + (indexRequired ? "required" : "recommended") +
-                " to view files of this size.   Click \"Go\" to create one now.";
+                " to view files of this size.   Click \"Go\" to create one now or \"Cancel" +
+                " to proceed without an index.";
         IndexCreatorDialog dialog = IndexCreatorDialog.createShowDialog(IGV.getMainFrame(), baseFile, newIdxFile, messageText);
         return (Index) dialog.getIndex();
     }
@@ -136,6 +136,8 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
     public abstract boolean isIndexed();
 
+    public abstract Index getIndex();
+
     public Class getFeatureClass() {
         return featureClass;
     }
@@ -174,7 +176,7 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
                     }
                 }
             }
-       }
+        }
 
 
         @Override
@@ -182,6 +184,11 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
             return true;
         }
 
+        @Override
+        public Index getIndex() {
+            return this.reader.getIndex();
+        }
+
         @Override
         public Iterator<Feature> getFeatures(String chr, int start, int end) throws IOException {
 
@@ -222,10 +229,9 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
         protected int estimateFeatureWindowSize(FeatureReader reader) {
 
             // Simple formula for VCF.  Appropriate for human 1KG/dbSNp, probably overly conservative otherwise
-            if(isVCF) {
-                 return 10000;
-            }
-            else {
+            if (isVCF) {
+                return 10000;
+            } else {
 
             }
             CloseableTribbleIterator<htsjdk.tribble.Feature> iter = null;
@@ -312,7 +318,7 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
                     if (f instanceof NamedFeature) FeatureDB.addFeature((NamedFeature) f, genome);
                 }
             } finally {
-                if(iter instanceof CloseableTribbleIterator) {
+                if (iter instanceof CloseableTribbleIterator) {
                     ((CloseableTribbleIterator) iter).close();
                 }
             }
@@ -333,6 +339,11 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
             return false;
         }
 
+        @Override
+        public Index getIndex() {
+            return null;
+        }
+
         @Override
         public List<LocusScore> getCoverageScores(String chr, int start, int end, int zoom) {
             return coverageData == null ? Collections.<LocusScore>emptyList() :
