@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 /*
  * IGVCommandBar.java
  *
@@ -47,6 +62,8 @@ import org.broad.igv.util.LongRunningTask;
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
 import javax.swing.border.LineBorder;
+import javax.swing.event.PopupMenuEvent;
+import javax.swing.event.PopupMenuListener;
 import javax.swing.text.JTextComponent;
 import java.awt.*;
 import java.awt.event.ActionEvent;
@@ -79,6 +96,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
     private JideButton refreshButton;
     private JideToggleButton roiToggleButton;
     private JideButton detailsBehaviorButton;
+    private JideToggleButton rulerLineButton;
     private JTextField searchTextField;
     private JPanel toolPanel;
     private JPanel zoomControl;
@@ -129,6 +147,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
             }
         });
 
+
         getDefaultReferenceFrame().getEventBus().register(this);
     }
 
@@ -237,7 +256,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
 
                         monitor.fireProgressChange(25);
 
-                        FrameManager.getDefaultFrame().setChromosomeName(Globals.CHR_ALL, true);
+                        FrameManager.getDefaultFrame().setChromosomeName(genome.getHomeChromosome(), true);
                         IGV.getInstance().doRefresh();
 
                     } catch (GenomeServerException e) {
@@ -248,8 +267,8 @@ public class IGVCommandBar extends javax.swing.JPanel {
                     } catch (IOException e) {
                         int choice =
                                 JOptionPane.showConfirmDialog(
-                                        IGV.getMainFrame(), "The genome file [" + e.getMessage() +
-                                        "] could not be read. Would you like to remove the selected entry?",
+                                        IGV.getMainFrame(), "The genome file [" + genomeListItem.getLocation() +
+                                                "] could not be read. Would you like to remove the selected entry?",
                                         "", JOptionPane.OK_CANCEL_OPTION);
 
                         if (choice == JOptionPane.OK_OPTION) {
@@ -444,18 +463,22 @@ public class IGVCommandBar extends javax.swing.JPanel {
 
                 label.setOpaque(true);
                 label.setBorder(new EmptyBorder(1, 1, 1, 1));
+                label.setSize(label.getWidth() + 10, label.getHeight());
                 renderer = label;
             }
 
-            if (isSelected) {
-                renderer.setBackground(list.getSelectionBackground());
-                renderer.setForeground(list.getSelectionForeground());
-            } else {
-                renderer.setBackground(list.getBackground());
-                renderer.setForeground(list.getForeground());
+            //We call with a null list when setting width
+            if (list != null) {
+                if (isSelected) {
+                    renderer.setBackground(list.getSelectionBackground());
+                    renderer.setForeground(list.getSelectionForeground());
+                } else {
+                    renderer.setBackground(list.getBackground());
+                    renderer.setForeground(list.getForeground());
+                }
+                renderer.setFont(list.getFont());
             }
 
-            renderer.setFont(list.getFont());
 
             return renderer;
         }
@@ -582,6 +605,28 @@ public class IGVCommandBar extends javax.swing.JPanel {
         genomeComboBox = new JComboBox();
         genomeComboBox.setMinimumSize(new Dimension(180, 27));
         genomeComboBox.setPreferredSize(new Dimension(180, 27));
+
+        genomeComboBox.addPopupMenuListener(new PopupMenuListener() {
+            @Override
+            public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
+                try {
+                    adjustPopupWidth(genomeComboBox);
+                } catch (Exception e1) {
+                    log.warn(e1.getMessage(), e1);
+                }
+            }
+
+            @Override
+            public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
+                //TODO
+            }
+
+            @Override
+            public void popupMenuCanceled(PopupMenuEvent e) {
+                //TODO
+            }
+        });
+
         locationPanel.add(genomeComboBox, JideBoxLayout.FIX);
         locationPanel.add(Box.createHorizontalStrut(5), JideBoxLayout.FIX);
 
@@ -755,29 +800,22 @@ public class IGVCommandBar extends javax.swing.JPanel {
         detailsBehaviorButton.setPreferredSize(new java.awt.Dimension(32, 32));
         toolPanel.add(detailsBehaviorButton, JideBoxLayout.FIX);
 
-        boolean showExomeButton = !Globals.isProduction();
-        if (showExomeButton) {
-            exomeButton = new JideButton();
-            exomeButton.setButtonStyle(JideButton.TOOLBAR_STYLE);
-            exomeButton.setText(FrameManager.isExomeMode() ? "Genome" : "Exome");
-            exomeButton.setToolTipText("Click to toggle between 'exome' and 'genome' views");
-            exomeButton.addActionListener(new ActionListener() {
-
-                @Override
-                public void actionPerformed(ActionEvent actionEvent) {
-
-                    int modifiers = actionEvent.getModifiers();
-                    boolean showTrackMenu = (modifiers & ActionEvent.ALT_MASK) > 0;
-
-                    boolean newMode = !FrameManager.isExomeMode();
-                    if (!FrameManager.setExomeMode(newMode, showTrackMenu)) return;
-                    String label = newMode ? "Genome" : "Exome";
-                    exomeButton.setText(label);
-                    IGV.getInstance().resetFrames();
-                }
-            });
-            toolPanel.add(exomeButton, JideBoxLayout.FIX);
-        }
+        rulerLineButton = new JideToggleButton();
+        //roiToggleButton.setButtonStyle(JideButton.TOOLBOX_STYLE);
+        //roiToggleButton.setBorder(toolButtonBorder);
+        rulerLineButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/images/vertical-line.gif")));
+        rulerLineButton.setAlignmentX(RIGHT_ALIGNMENT);
+        rulerLineButton.setToolTipText("Enable ruler line in data panels");
+        rulerLineButton.setMaximumSize(new java.awt.Dimension(32, 32));
+        rulerLineButton.setMinimumSize(new java.awt.Dimension(32, 32));
+        rulerLineButton.setPreferredSize(new java.awt.Dimension(32, 32));
+        rulerLineButton.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                IGV.getInstance().setRulerEnabled(rulerLineButton.isSelected());
+                IGV.getInstance().repaintDataPanels();
+            }
+        });
+        toolPanel.add(rulerLineButton, JideBoxLayout.FIX);
 
         this.add(toolPanel);
 
@@ -817,6 +855,41 @@ public class IGVCommandBar extends javax.swing.JPanel {
         revalidate();
     }
 
+    /**
+     * Adjust the popup for the combobox to be at least as wide as
+     * the widest item.
+     *
+     * @param box
+     */
+    private void adjustPopupWidth(JComboBox box) {
+        if (box.getItemCount() == 0) return;
+        Object comp = box.getUI().getAccessibleChild(box, 0);
+        if (!(comp instanceof JPopupMenu)) {
+            return;
+        }
+        JPopupMenu popup = (JPopupMenu) comp;
+        JScrollPane scrollPane = null;
+        for (Component scomp : popup.getComponents()) {
+            if (scomp instanceof JScrollPane) {
+                scrollPane = (JScrollPane) scomp;
+            }
+        }
+        if (scrollPane == null) return;
+
+        //Loop through and set width to widest component, plus some padding
+        int rendererWidth = box.getWidth();
+        for (int index = 0; index < box.getItemCount(); index++) {
+            Object value = box.getItemAt(index);
+            Component rendererComp = box.getRenderer().getListCellRendererComponent(null, value, index, false, false);
+        }
+
+        Dimension size = scrollPane.getPreferredSize();
+        size.width = Math.max(size.width, rendererWidth);
+        scrollPane.setPreferredSize(size);
+        scrollPane.setMaximumSize(size);
+        scrollPane.revalidate();
+    }
+
     private void homeButtonActionPerformed(java.awt.event.ActionEvent evt) {
         Genome genome = GenomeManager.getInstance().getCurrentGenome();
         if (FrameManager.isGeneListMode()) {
@@ -825,7 +898,8 @@ public class IGVCommandBar extends javax.swing.JPanel {
         if (genome != null) {
             String chrName = genome.getHomeChromosome();
             if (chrName != null && !chrName.equals(chromosomeComboBox.getSelectedItem())) {
-                ViewChange.ChromosomeChangeCause cause = new ViewChange.ChromosomeChangeCause(evt.getSource(), chrName);
+                Object source = (evt == null ? null : evt.getSource());
+                ViewChange.ChromosomeChangeCause cause = new ViewChange.ChromosomeChangeCause(source, chrName);
                 cause.setRecordHistory(true);
                 getDefaultReferenceFrame().getEventBus().post(cause);
             }
@@ -878,8 +952,13 @@ public class IGVCommandBar extends javax.swing.JPanel {
         }
 
         if ((searchText != null) && (searchText.length() > 0)) {
-            searchTextField.setText(searchText);
-            (new SearchCommand(getDefaultReferenceFrame(), searchText)).execute();
+            String homeChr = IGV.getInstance().getGenomeManager().getCurrentGenome().getHomeChromosome();
+            if (searchText.equalsIgnoreCase("home") || searchText.equalsIgnoreCase(homeChr)) {
+                homeButtonActionPerformed(null);
+            } else {
+                searchTextField.setText(searchText);
+                (new SearchCommand(getDefaultReferenceFrame(), searchText)).execute();
+            }
             //This is not necessary, since we receive a ViewChange.Result later
             //chromosomeComboBox.setSelectedItem(getDefaultReferenceFrame().getChrName());
         }
@@ -917,6 +996,8 @@ public class IGVCommandBar extends javax.swing.JPanel {
             if (text.length() <= 1) {
                 return false;
             } else {
+                //TODO Uncomment to use comprehensive feature search, note that it should support partial matches
+                //List<NamedFeature> features = SearchCommand.comprehensiveFeatureSearch(text);
                 List<NamedFeature> features = FeatureDB.getFeaturesList(text, SearchCommand.SEARCH_LIMIT);
                 final List<SearchCommand.SearchResult> results = SearchCommand.getResults(features);
                 Object[] list = SearchCommand.getSelectionList(results, false);
