@@ -28,7 +28,8 @@ package org.broad.igv.ui;
 
 //~--- JDK imports ------------------------------------------------------------
 
-import java.awt.*;
+import org.broad.igv.ui.util.UIUtilities;
+
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
@@ -51,22 +52,21 @@ public class WaitCursorManager {
      */
     static Set<CursorToken> tokens = Collections.synchronizedSet(new HashSet());
 
-    /**
-     * The wait cursor, defined statically for convenience.
-     */
-    static Cursor waitCursor = Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR);
 
     /**
      * Show the wait cursor on all components.  Add a token to represent this invocation of
      * showWaitCursor
      *
      * @return token representing this invocation.  This token should be used by clients to remove
-     *         the wait cursor.  This should be done in a finally block to insure removal.
+     * the wait cursor.  This should be done in a finally block to insure removal.
      */
     public static CursorToken showWaitCursor() {
+
         IGV.getRootPane().getGlassPane().setVisible(true);
         CursorToken token = new CursorToken();
         tokens.add(token);
+
+        //if(tokens.size() == 1) UIUtilities.activateMainFrame();   // neccessary for busy cursor
         // Return a token representing this wait cursor set.  The token is used to release the
         // wait cursor.
         return token;
