@@ -26,9 +26,9 @@
 package org.broad.igv.ui.panel;
 
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.exceptions.DataLoadException;
-import org.broad.igv.track.TrackGroup;
+import org.broad.igv.renderer.DataRange;
+import org.broad.igv.track.*;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.MessageCollection;
 import org.broad.igv.ui.util.MessageUtils;
@@ -40,9 +40,7 @@ import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.Transferable;
 import java.awt.dnd.*;
 import java.io.File;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Comparator;
+import java.util.*;
 import java.util.List;
 
 /**
@@ -55,6 +53,7 @@ public class DataPanelContainer extends TrackPanelComponent implements Paintable
 
     TrackPanel parent;
 
+
     public DataPanelContainer(TrackPanel trackPanel) {
         super(trackPanel);
 
@@ -141,8 +140,11 @@ public class DataPanelContainer extends TrackPanelComponent implements Paintable
 
     @Override
     protected void paintChildren(Graphics g) {
+
+        autoscale();
+
         super.paintChildren(g);
-        if(IGV.getInstance().isRulerEnabled()) {
+        if (IGV.getInstance().isRulerEnabled()) {
             int start = MouseInfo.getPointerInfo().getLocation().x - getLocationOnScreen().x;
             g.setColor(Color.BLACK);
             g.drawLine(start, 0, start, getHeight());
@@ -150,7 +152,6 @@ public class DataPanelContainer extends TrackPanelComponent implements Paintable
     }
 
 
-
     private class FileDropTargetListener implements DropTargetListener {
 
         private TrackPanel panel;
@@ -249,4 +250,117 @@ public class DataPanelContainer extends TrackPanelComponent implements Paintable
     }
 
 
+    private void autoscale() {
+
+        final Collection<Track> trackList = IGV.getInstance().getAllTracks();
+
+        Map<String, List<Track>> autoscaleGroups = new HashMap<String, List<Track>>();
+
+        for (Track track : trackList) {
+
+            if (!track.isVisible()) continue;
+
+            String asGroup = track.getAttributeValue(AttributeManager.GROUP_AUTOSCALE);
+            if (asGroup != null) {
+                if (!autoscaleGroups.containsKey(asGroup)) {
+                    autoscaleGroups.put(asGroup, new ArrayList<Track>());
+                }
+
+                if (track instanceof MergedTracks) {
+                    for (Track mt : ((MergedTracks) track).getMemberTracks()) {
+                        autoscaleGroups.get(asGroup).add(track);
+                    }
+                } else {
+                    autoscaleGroups.get(asGroup).add(track);
+                }
+            } else if (track.getAutoScale()) {
+
+                if (track instanceof MergedTracks) {
+                    for (Track mt : ((MergedTracks) track).getMemberTracks()) {
+                        autoscaleGroup(Arrays.asList(mt));
+                    }
+                } else {
+                    autoscaleGroup(Arrays.asList(track));
+                }
+            }
+
+
+        }
+
+        if (autoscaleGroups.size() > 0) {
+            for (List<Track> tracks : autoscaleGroups.values()) {
+                autoscaleGroup(tracks);
+            }
+        }
+    }
+
+    private void autoscaleGroup(List<Track> trackList) {
+
+
+        List<ReferenceFrame> frames =
+                FrameManager.isGeneListMode() ? FrameManager.getFrames() :
+                        Arrays.asList(FrameManager.getDefaultFrame());
+
+
+        List<Range> inViewRanges = new ArrayList<Range>();
+
+        synchronized (trackList) {
+            for (Track track : trackList) {
+                if (track instanceof ScalableTrack) {
+                    for (ReferenceFrame frame : frames) {
+                        Range range = ((ScalableTrack) track).getInViewRange(frame);
+                        if (range != null) {
+                            inViewRanges.add(range);
+                        }
+                    }
+                }
+            }
+
+            if (inViewRanges.size() > 0) {
+
+                Range inter = computeScale(inViewRanges);
+
+                for (Track track : trackList) {
+
+                    DataRange dr = track.getDataRange();
+                    float min = Math.min(0, inter.min);
+                    float base = Math.max(min, dr.getBaseline());
+                    float max = inter.max;
+                    // Pathological case where min ~= max  (no data in view)
+                    if (max - min <= (2 * Float.MIN_VALUE)) {
+                        max = min + 1;
+                    }
+
+                    DataRange newDR = new DataRange(min, base, max, dr.isDrawBaseline());
+                    newDR.setType(dr.getType());
+                    track.setDataRange(newDR);
+
+                }
+            }
+        }
+    }
+
+
+    public static Range computeScale(List<Range> ranges) {
+
+        float min = 0;
+        float max = 0;
+
+        if (ranges.size() > 0) {
+            max = ranges.get(0).max;
+            min = ranges.get(0).min;
+
+            for (int i = 1; i < ranges.size(); i++) {
+
+                Range r = ranges.get(i);
+                max = Math.max(r.max, max);
+                min = Math.min(r.min, min);
+
+            }
+        }
+
+        return new Range(min, max);
+    }
+
+
 }
