@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.ui.panel;
@@ -14,6 +28,7 @@ package org.broad.igv.ui.panel;
 import com.jidesoft.swing.JideSplitPane;
 import org.apache.log4j.Logger;
 import org.broad.igv.PreferenceManager;
+import org.broad.igv.session.Session;
 import org.broad.igv.track.AttributeManager;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.SnapshotUtilities;
@@ -242,10 +257,9 @@ public class MainPanel extends JPanel implements Paintable {
 
 
     /**
-     * Called from IGV.resetSession()
+     * Removes user added panels. Used for resetting sessions
      */
     public void resetPanels() {
-        // Remove user added panels
         for (TrackPanel tp : getTrackPanels()) {
             tp.clearTracks();
             final TrackPanelScrollPane tsp = tp.getScrollPane();
@@ -430,7 +444,14 @@ public class MainPanel extends JPanel implements Paintable {
 
                 // Width is in floating point because we need to fill data panel,  going straight to an "int" here
                 // would cause truncation
-                float wc = ((float) dataPanelWidth - (frames.size() - 1) * gap) / frames.size();
+                Session.GeneListMode mode = IGV.hasInstance() ?
+                        IGV.getInstance().getSession().getGeneListMode() :
+                        Session.GeneListMode.NORMAL;
+
+                float wc =  mode == Session.GeneListMode.NORMAL ?
+                        ((float) dataPanelWidth - (frames.size() - 1) * gap) / frames.size() :
+                        20;
+
                 for (int i = 0; i < frames.size(); i++) {
                     ReferenceFrame frame = frames.get(i);
                     int nextX = (int) ((i + 1) * (wc + gap));
