@@ -133,9 +133,14 @@ public class HttpUtils {
      * @throws IOException
      */
     public String getContentsAsString(URL url) throws IOException {
+       return getContentsAsString(url, null);
+    }
 
+
+    public String getContentsAsString(URL url, Map<String, String> headers) throws IOException {
         InputStream is = null;
-        HttpURLConnection conn = openConnection(url, null);
+
+        HttpURLConnection conn = openConnection(url, headers);
         try {
             is = conn.getInputStream();
             return readContents(is);
@@ -144,8 +149,8 @@ public class HttpUtils {
             throw e;
         } finally {
             if (is != null) is.close();
-        }
-    }
+        }    }
+
 
     public String getContentsAsJSON(URL url) throws IOException {
 
@@ -453,7 +458,7 @@ public class HttpUtils {
             urlDownloader.run();
             return urlDownloader;
         } else {
-            ProgressMonitor monitor = new ProgressMonitor();
+            javax.swing.ProgressMonitor monitor = new javax.swing.ProgressMonitor(IGV.getInstance().getMainPanel(), "Downloading " + outputFile.getName(), "", 0, 100);
             urlDownloader.setMonitor(monitor);
             ActionListener buttonListener = new ActionListener() {
                 @Override
@@ -461,15 +466,15 @@ public class HttpUtils {
                     urlDownloader.cancel(true);
                 }
             };
-            String permText = "Downloading " + url;
-            String title = dialogTitle != null ? dialogTitle : permText;
-            CancellableProgressDialog dialog = CancellableProgressDialog.showCancellableProgressDialog(dialogsParent, title, buttonListener, false, monitor);
-            dialog.setPermText(permText);
+          //  String permText = "Downloading " + url;
+          //  String title = dialogTitle != null ? dialogTitle : permText;
+          //  CancellableProgressDialog dialog = CancellableProgressDialog.showCancellableProgressDialog(dialogsParent, title, buttonListener, false, monitor);
+          //  dialog.setPermText(permText);
 
-            Dimension dms = new Dimension(600, 150);
-            dialog.setPreferredSize(dms);
-            dialog.setSize(dms);
-            dialog.validate();
+          //  Dimension dms = new Dimension(600, 150);
+          //  dialog.setPreferredSize(dms);
+          //  dialog.setSize(dms);
+          //  dialog.validate();
 
             LongRunningTask.submit(urlDownloader);
             return urlDownloader;
@@ -761,7 +766,8 @@ public class HttpUtils {
             if (host.equals("igv.broadinstitute.org")) {
                 urlString = urlString.replace("igv.broadinstitute.org", "s3.amazonaws.com/igv.broadinstitute.org");
             } else if (host.equals("igvdata.broadinstitute.org")) {
-                urlString = urlString.replace("igvdata.broadinstitute.org", "dn7ywbm9isq8j.cloudfront.net");
+                // Drop support for cloudfront server
+                urlString = urlString.replace("igvdata.broadinstitute.org", "s3.amazonaws.com/igv.broadinstitute.org");
             } else if (host.equals("www.broadinstitute.org")) {
                 urlString = urlString.replace("www.broadinstitute.org/igvdata", "data.broadinstitute.org/igvdata");
             }
@@ -837,8 +843,9 @@ public class HttpUtils {
                 } catch (IOException e) {
                     log.error("Error while testing byte range " + e.getMessage());
                     // We could not reach the test server, so we can't know if this client can do byte-range tests or
-                    // not.  Take the "optimistic" view.
-                    return true;
+                    // not.  Take the "pessimistic" view.
+                    byteRangeTestMap.put(host, false);
+                    return false;
                 } finally {
                     if (str != null) try {
                         str.close();
@@ -888,7 +895,6 @@ public class HttpUtils {
         return map;
     }
 
-
     public static class ProxySettings {
         boolean auth = false;
         String user;
