@@ -146,21 +146,19 @@ public class VariantRenderer { //extends FeatureRenderer {
         final boolean useAlpha = variant.isFiltered();
         final Color alleleColor;
         final Color refColor;
-        double percent;
+        double percent = 0;
         if (track.getColorMode() == VariantTrack.ColorMode.METHYLATION_RATE) {
             alleleColor = this.convertMethylationRateToColor((float) variant.getMethlationRate() / 100);
             percent = variant.getCoveredSampleFraction();
             refColor = useAlpha ? colorAlleleRefAlpha : colorAlleleRef;   // Gray
         } else {
             alleleColor = useAlpha ? colorAlleleBandVarAlpha : colorAlleleBandVar; // Red
-            double af = variant.getAlleleFraction();
-            if (af < 0) {
-                double[] afreqs = variant.getAlleleFreqs();
-                if (afreqs != null && afreqs.length > 0) {
-                    af = afreqs[0];
-                }
-            }
+
+            double af = track.getSiteColorMode() == VariantTrack.ColorMode.ALLELE_FREQUENCY ?
+                    variant.getAlternateAlleleFrequency() :
+                    variant.getAlleleFraction();
             percent = Math.min(1, af);
+
             if (percent <= 0) {
                 percent = 0;
                 refColor = useAlpha ? colorAlleleRefAlpha : colorAlleleRef;   // Gray
@@ -224,11 +222,6 @@ public class VariantRenderer { //extends FeatureRenderer {
 
         Genotype genotype = variant.getGenotype(sampleName);
 
-        if (sampleName.equals("CYP26B1-B12")) {
-            System.out.println(genotype.getTypeString() + "   " + genotype.getGenotypeString() + "  " + isFiltered);
-        }
-
-
         if (genotype == null) {
             log.error("Genotype not found for sample " + sampleName);
         } else {
@@ -244,17 +237,6 @@ public class VariantRenderer { //extends FeatureRenderer {
                     b2Color = b1Color;
                     break;
 
-                case ALLELE:
-                    final List<Allele> alleleList = genotype.getAlleles();
-                    if (alleleList.size() > 0) {
-                        b1 = getFirstBase(alleleList.get(0));
-                        b1Color = nucleotideColors.get(b1);
-                    }
-                    if (alleleList.size() > 1) {
-                        b2 = getFirstBase(alleleList.get(1));
-                        b2Color = nucleotideColors.get(b2);
-                    }
-                    break;
                 case METHYLATION_RATE:
 
                     final double goodBaseCount = genotype.getAttributeAsDouble("GB");
