@@ -75,8 +75,9 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     private static final Color borderGray = new Color(200, 200, 200);
 
     private final static int DEFAULT_EXPANDED_GENOTYPE_HEIGHT = 15;
-    private final int DEFAULT_SQUISHED_GENOTYPE_HEIGHT = 4;
+    private final static int DEFAULT_SQUISHED_GENOTYPE_HEIGHT = 4;
     private final static int DEFAULT_VARIANT_BAND_HEIGHT = 25;
+    private final static int DEFAULT_SQUISHED_VARIANT_BAND_HEIGHT = 10;
     private final static int MAX_FILTER_LINES = 15;
 
 
@@ -114,6 +115,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     /**
      * The height of the top band representing the variant call
      */
+    @XmlAttribute
     private int variantBandHeight = DEFAULT_VARIANT_BAND_HEIGHT;
 
     /**
@@ -124,11 +126,13 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     /**
      * Boolean indicating if samples are grouped.
      */
+    @XmlAttribute
     private boolean grouped;
 
     /**
      * The id of the group used to group samples.
      */
+    @XmlAttribute
     private String groupByAttribute;
 
     /**
@@ -143,6 +147,9 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
      */
     private ColorMode coloring = ColorMode.GENOTYPE;
 
+
+    private ColorMode siteColorMode;
+
     /**
      * When true, variants that are marked filtering are not drawn.
      */
@@ -188,7 +195,12 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     public VariantTrack(ResourceLocator locator, FeatureSource source, List<String> samples,
                         boolean enableMethylationRateSupport) {
         super(locator, source);
-        String path = locator != null ? locator.getPath() : null;
+
+        PreferenceManager prefMgr = PreferenceManager.getInstance();
+
+        String path = locator == null ? null : locator.getPath();
+
+
         this.renderer = new VariantRenderer(this);
 
         this.enableMethylationRateSupport = enableMethylationRateSupport;
@@ -197,6 +209,9 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
             coloring = ColorMode.METHYLATION_RATE;
         }
 
+        this.siteColorMode = prefMgr.getAsBoolean(PreferenceManager.VARIANT_COLOR_BY_ALLELE_FREQ) ?
+                ColorMode.ALLELE_FREQUENCY :
+                ColorMode.ALLELE_FRACTION;
 
         this.allSamples = samples;
 
@@ -211,9 +226,16 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         }
 
         // If sample->bam list file is supplied enable vcfToBamMode.
-        boolean bypassFileAutoDiscovery = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.BYPASS_FILE_AUTO_DISCOVERY);
-        String vcfToBamMapping = path != null ? path + ".mapping" : null;
-        if (!bypassFileAutoDiscovery && ParsingUtils.pathExists(vcfToBamMapping)) {
+        String vcfToBamMapping = locator == null ? null : locator.getMappingPath();
+
+        boolean bypassFileAutoDiscovery = prefMgr.getAsBoolean(PreferenceManager.BYPASS_FILE_AUTO_DISCOVERY);
+        if (vcfToBamMapping == null && path != null && !bypassFileAutoDiscovery) {
+            if (ParsingUtils.pathExists(path + ".mapping")) {
+                vcfToBamMapping = path + ".mapping";
+            }
+        }
+
+        if (vcfToBamMapping != null && !vcfToBamMapping.equals(".")) {
             loadAlignmentMappings(vcfToBamMapping);
         }
 
@@ -221,7 +243,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         // Ugly test on source is to avoid having to add "isIndexed" to a zillion feature source classes.  The intent
         // is to skip this if using a non-indexed source.
         if (!(source instanceof TribbleFeatureSource && ((TribbleFeatureSource) source).isIndexed() == false)) {
-            int defVisibilityWindow = PreferenceManager.getInstance().getAsInt(PreferenceManager.DEFAULT_VISIBILITY_WINDOW);
+            int defVisibilityWindow = prefMgr.getAsInt(PreferenceManager.DEFAULT_VISIBILITY_WINDOW);
             if (defVisibilityWindow > 0) {
                 setVisibilityWindow(defVisibilityWindow * 1000);
             } else {
@@ -418,6 +440,21 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         }
     }
 
+    @Override
+    public void setDisplayMode(DisplayMode mode) {
+
+        variantBandHeight = mode == DisplayMode.SQUISHED ? DEFAULT_SQUISHED_VARIANT_BAND_HEIGHT : DEFAULT_VARIANT_BAND_HEIGHT;
+
+        if(mode == DisplayMode.SQUISHED) {
+            // Compute row height needed to display all genotypes, if possible
+            final int groupCount = samplesByGroups.size();
+            final int margins = (groupCount - 1) * 3;
+            int sampleCount = allSamples.size();
+            squishedHeight = Math.min(DEFAULT_SQUISHED_GENOTYPE_HEIGHT, Math.max(1, (height - variantBandHeight - margins) / sampleCount));
+        }
+
+        super.setDisplayMode(mode);
+    }
 
     /**
      * Render the features in the supplied rectangle.
@@ -839,6 +876,15 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     }
 
 
+    @XmlAttribute
+    public ColorMode getSiteColorMode() {
+        return siteColorMode;
+    }
+
+    public void setSiteColorMode(ColorMode siteColorMode) {
+        this.siteColorMode = siteColorMode;
+    }
+
     public String getNameValueString(int y) {
         if (y < top + variantBandHeight) {
             return getName();
@@ -974,8 +1020,10 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         toolTip.append("<br>ID: " + id);
         toolTip.append("<br>Reference: " + variant.getReference());
         List<Allele> alternates = variant.getAlternateAlleles();
+        String alternateString = null;
         if (alternates.size() > 0) {
-            toolTip.append("<br>Alternate: " + StringUtils.join(alternates, ","));
+            alternateString = StringUtils.join(alternates, ",");
+            toolTip.append("<br>Alternate: " + alternateString);
         }
 
         toolTip.append("<br>Qual: " + numFormat.format(variant.getPhredScaledQual()));
@@ -986,37 +1034,47 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         } else {
             toolTip.append("<br>Is Filtered Out: No</b><br>");
         }
-        toolTip.append("<br><b>Alleles:</b>");
-        toolTip.append(getAlleleToolTip(variant));
 
-        double[] af = variant.getAlleleFreqs();
-        if (af[0] < 0 && variant.getSampleNames().size() > 0) {
-            af = new double[]{variant.getAlleleFraction()};
-        }
-        String afMsg = "Unknown";
-        if (af[0] >= 0) {
-            afMsg = numFormat.format(af[0]);
-            for (int ii = 1; ii < af.length; ii++) {
-                afMsg += ", " + numFormat.format(af[ii]);
+        if (alternateString != null) {
+            toolTip.append("<br><b>Alleles:</b>");
+
+            toolTip.append("<br>Alternate Alleles: " + alternateString);
+
+            int[] ac = variant.getAlleleCounts();
+            if (ac != null) {
+                String acString = ac.length > 1 ? "<br>Allele Counts: " : "<br>Allele Count: ";
+                for (int i = 0; i < ac.length; i++) {
+                    acString += Integer.toString(ac[i]);
+                    if (i < ac.length - 1) acString += ", ";
+                }
+                toolTip.append(acString);
             }
-        }
-        toolTip.append("<br>Allele Frequency: " + afMsg + "<br>");
 
-        if (variant.getSampleNames().size() > 0) {
-            double afrac = variant.getAlleleFraction();
-            toolTip = toolTip.append("<br>Minor Allele Fraction: " + numFormat.format(afrac) + "<br>");
+            int totalAlleleCount = variant.getTotalAlleleCount();
+            if (totalAlleleCount > 0) {
+                toolTip.append("<br>Total # Alleles: " + String.valueOf(totalAlleleCount));
+            }
+
+            double[] af = variant.getAlleleFreqs();
+            String afString = af.length > 1 ? "<br>Allele Fequencies: " : "<br>Allele Frequency: ";
+            for (int i = 0; i < af.length; i++) {
+                afString += Double.toString(af[i]);
+                if (i < af.length - 1) afString += ", ";
+            }
+            toolTip.append(afString);
+        }
+        if (variant.getAttributes().size() > 0) {
+            toolTip.append(getVariantInfo(variant));
         }
 
-        toolTip.append("<br><b>Genotypes:</b>");
-        toolTip.append(getGenotypesSummaryTooltip(variant) + "<br>");
-        toolTip.append(getVariantInfo(variant) + "<br>");
+
         return toolTip.toString();
     }
 
     protected String getVariantInfo(Variant variant) {
         Set<String> keys = variant.getAttributes().keySet();
         if (keys.size() > 0) {
-            String toolTip = "<br><b>Variant Attributes</b>";
+            String toolTip = "<br><br><b>Variant Attributes</b>";
             int count = 0;
 
             // Put AF and GMAF and put at the top, if present
@@ -1025,6 +1083,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
             if (afValue != null && afValue.length() > 0 && !afValue.equals("null")) {
                 toolTip = toolTip.concat("<br>" + getFullName(k) + ": " + variant.getAttributeAsString(k));
             }
+
             k = "GMAF";
             afValue = variant.getAttributeAsString(k);
             if (afValue != null && afValue.length() > 0 && !afValue.equals("null")) {
@@ -1101,7 +1160,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     }
 
     public static enum ColorMode {
-        GENOTYPE, METHYLATION_RATE, ALLELE
+        GENOTYPE, METHYLATION_RATE, ALLELE_FREQUENCY, ALLELE_FRACTION
     }
 
     public static enum BackgroundType {
@@ -1113,8 +1172,8 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
 
     static {
         fullNames.put("AA", "Ancestral Allele");
-        fullNames.put("AC", "Allele Count in Genotypes");
-        fullNames.put("AN", "Total Alleles in Genotypes");
+        fullNames.put("AC", "Allele Count");
+        fullNames.put("AN", "Total Alleles");
         fullNames.put("AF", "Allele Frequency");
         fullNames.put("DP", "Depth");
         fullNames.put("MQ", "Mapping Quality");
@@ -1180,33 +1239,6 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         return toolTip;
     }
 
-    private String getAlleleToolTip(Variant counts) {
-        double noCall = counts.getNoCallCount() * 2;
-        double aNum = (counts.getHetCount() + counts.getHomRefCount() + counts.getHomVarCount()) * 2;
-        double aCount = (counts.getHomVarCount() * 2 + counts.getHetCount()) * 2;
-
-        String toolTip = "<br>No Call: " + (int) noCall;
-        toolTip = toolTip.concat("<br>Allele Num: " + (int) aNum);
-        toolTip = toolTip.concat("<br>Allele Count: " + (int) aCount);
-        return toolTip;
-    }
-
-    private String getGenotypesSummaryTooltip(Variant counts) {
-        int noCall = counts.getNoCallCount();
-        int homRef = counts.getHomRefCount();
-        int nonVar = noCall + homRef;
-        int het = counts.getHetCount();
-        int homVar = counts.getHomVarCount();
-        int var = het + homVar;
-
-        String toolTip = "<br>Non Variant: " + nonVar;
-        toolTip = toolTip.concat("<br> - No Call: " + noCall);
-        toolTip = toolTip.concat("<br> - Hom Ref: " + homRef);
-        toolTip = toolTip.concat("<br>Variant: " + var);
-        toolTip = toolTip.concat("<br> - Het: " + het);
-        toolTip = toolTip.concat("<br> - Hom Var: " + homVar);
-        return toolTip;
-    }
 
     /**
      * Return the {@code Variant} object closest to the specified event
